; Copyright (C) 2014-2020 Joonas Javanainen <joonas.javanainen@gmail.com>
;
; Permission is hereby granted, free of charge, to any person obtaining a copy
; of this software and associated documentation files (the "Software"), to deal
; in the Software without restriction, including without limitation the rights
; to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
; copies of the Software, and to permit persons to whom the Software is
; furnished to do so, subject to the following conditions:
;
; The above copyright notice and this permission notice shall be included in
; all copies or substantial portions of the Software.
;
; THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
; IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
; FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
; AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
; LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
; OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
; SOFTWARE.

; Tests the DAA instruction with all possible input combinations

; Verified results:
;   pass: DMG, MGB, SGB, SGB2, CGB, AGB, AGS
;   fail: -

.include "common.s"

  ld sp, DEFAULT_SP

  ld hl, testcases1
  call run_tests
  ld hl, testcases2
  call run_tests

  quit_ok

; Inputs
;   HL testcase pointer
run_tests:
  ld (hram.sp_save_l), sp
  ld sp, hram.f
  ld bc, $80*16
 
--
  ld a, h
  ldh (<hram.testcase_h), a
  ld a, l
  ldh (<hram.testcase_l), a
  ld a, (hl+)
  ldh (<hram.a), a
  ld a, (hl+)
  swap a
  ldh (<hram.f), a

  pop af
  daa
  push af

  ldh a, (<hram.a)
  cp (hl)
  jr nz, fail

  inc hl
  ldh a, (<hram.f)
  swap a
  cp (hl)
  jr nz, fail

  inc hl
  dec bc
  ld a, c
  or b
  jr nz, --

  ldh a, (<hram.sp_save_h)
  ld h, a
  ldh a, (<hram.sp_save_l)
  ld l, a
  ld sp, hl

  ret

fail:
  di
  ld sp, $fffe
  call disable_lcd_safe
  call reset_screen
  call print_load_font

  ldh a, (<hram.testcase_h)
  ld h, a
  ldh a, (<hram.testcase_l)
  ld l, a
  push hl

  ld hl, $9820
  print_string_literal "Test failed"

  call print_newline
  call print_newline
  print_string_literal "Input:"
  call print_newline

  print_string_literal "A: "
  pop bc
  ld a, (bc)
  inc bc
  push bc
  call print_hex8

  print_string_literal " F: "
  pop bc
  ld a, (bc)
  inc bc
  push bc
  call print_bin4

  call print_newline
  call print_newline
  print_string_literal "Expected output:"
  call print_newline

  print_string_literal "A: "
  pop bc
  ld a, (bc)
  inc bc
  push bc
  call print_hex8

  print_string_literal " F: "
  pop bc
  ld a, (bc)
  inc bc
  push bc
  call print_bin4

  call print_newline
  call print_newline
  print_string_literal "Actual output:"
  call print_newline

  print_string_literal "A: "
  ldh a, (<hram.a)
  call print_hex8

  print_string_literal " F: "
  ldh a, (<hram.f)
  swap a
  call print_bin4

  enable_lcd
  wait_vblank
  halt_execution

.bank 0 slot 0
.section "testcases1"
testcases1:
;   Before      After
;   A    flags  A    flags
.db $00, %0000, $00, %1000
.db $00, %0001, $60, %0001
.db $00, %0010, $06, %0000
.db $00, %0011, $66, %0001
.db $00, %0100, $00, %1100
.db $00, %0101, $a0, %0101
.db $00, %0110, $fa, %0100
.db $00, %0111, $9a, %0101
.db $00, %1000, $00, %1000
.db $00, %1001, $60, %0001
.db $00, %1010, $06, %0000
.db $00, %1011, $66, %0001
.db $00, %1100, $00, %1100
.db $00, %1101, $a0, %0101
.db $00, %1110, $fa, %0100
.db $00, %1111, $9a, %0101
.db $01, %0000, $01, %0000
.db $01, %0001, $61, %0001
.db $01, %0010, $07, %0000
.db $01, %0011, $67, %0001
.db $01, %0100, $01, %0100
.db $01, %0101, $a1, %0101
.db $01, %0110, $fb, %0100
.db $01, %0111, $9b, %0101
.db $01, %1000, $01, %0000
.db $01, %1001, $61, %0001
.db $01, %1010, $07, %0000
.db $01, %1011, $67, %0001
.db $01, %1100, $01, %0100
.db $01, %1101, $a1, %0101
.db $01, %1110, $fb, %0100
.db $01, %1111, $9b, %0101
.db $02, %0000, $02, %0000
.db $02, %0001, $62, %0001
.db $02, %0010, $08, %0000
.db $02, %0011, $68, %0001
.db $02, %0100, $02, %0100
.db $02, %0101, $a2, %0101
.db $02, %0110, $fc, %0100
.db $02, %0111, $9c, %0101
.db $02, %1000, $02, %0000
.db $02, %1001, $62, %0001
.db $02, %1010, $08, %0000
.db $02, %1011, $68, %0001
.db $02, %1100, $02, %0100
.db $02, %1101, $a2, %0101
.db $02, %1110, $fc, %0100
.db $02, %1111, $9c, %0101
.db $03, %0000, $03, %0000
.db $03, %0001, $63, %0001
.db $03, %0010, $09, %0000
.db $03, %0011, $69, %0001
.db $03, %0100, $03, %0100
.db $03, %0101, $a3, %0101
.db $03, %0110, $fd, %0100
.db $03, %0111, $9d, %0101
.db $03, %1000, $03, %0000
.db $03, %1001, $63, %0001
.db $03, %1010, $09, %0000
.db $03, %1011, $69, %0001
.db $03, %1100, $03, %0100
.db $03, %1101, $a3, %0101
.db $03, %1110, $fd, %0100
.db $03, %1111, $9d, %0101
.db $04, %0000, $04, %0000
.db $04, %0001, $64, %0001
.db $04, %0010, $0a, %0000
.db $04, %0011, $6a, %0001
.db $04, %0100, $04, %0100
.db $04, %0101, $a4, %0101
.db $04, %0110, $fe, %0100
.db $04, %0111, $9e, %0101
.db $04, %1000, $04, %0000
.db $04, %1001, $64, %0001
.db $04, %1010, $0a, %0000
.db $04, %1011, $6a, %0001
.db $04, %1100, $04, %0100
.db $04, %1101, $a4, %0101
.db $04, %1110, $fe, %0100
.db $04, %1111, $9e, %0101
.db $05, %0000, $05, %0000
.db $05, %0001, $65, %0001
.db $05, %0010, $0b, %0000
.db $05, %0011, $6b, %0001
.db $05, %0100, $05, %0100
.db $05, %0101, $a5, %0101
.db $05, %0110, $ff, %0100
.db $05, %0111, $9f, %0101
.db $05, %1000, $05, %0000
.db $05, %1001, $65, %0001
.db $05, %1010, $0b, %0000
.db $05, %1011, $6b, %0001
.db $05, %1100, $05, %0100
.db $05, %1101, $a5, %0101
.db $05, %1110, $ff, %0100
.db $05, %1111, $9f, %0101
.db $06, %0000, $06, %0000
.db $06, %0001, $66, %0001
.db $06, %0010, $0c, %0000
.db $06, %0011, $6c, %0001
.db $06, %0100, $06, %0100
.db $06, %0101, $a6, %0101
.db $06, %0110, $00, %1100
.db $06, %0111, $a0, %0101
.db $06, %1000, $06, %0000
.db $06, %1001, $66, %0001
.db $06, %1010, $0c, %0000
.db $06, %1011, $6c, %0001
.db $06, %1100, $06, %0100
.db $06, %1101, $a6, %0101
.db $06, %1110, $00, %1100
.db $06, %1111, $a0, %0101
.db $07, %0000, $07, %0000
.db $07, %0001, $67, %0001
.db $07, %0010, $0d, %0000
.db $07, %0011, $6d, %0001
.db $07, %0100, $07, %0100
.db $07, %0101, $a7, %0101
.db $07, %0110, $01, %0100
.db $07, %0111, $a1, %0101
.db $07, %1000, $07, %0000
.db $07, %1001, $67, %0001
.db $07, %1010, $0d, %0000
.db $07, %1011, $6d, %0001
.db $07, %1100, $07, %0100
.db $07, %1101, $a7, %0101
.db $07, %1110, $01, %0100
.db $07, %1111, $a1, %0101
.db $08, %0000, $08, %0000
.db $08, %0001, $68, %0001
.db $08, %0010, $0e, %0000
.db $08, %0011, $6e, %0001
.db $08, %0100, $08, %0100
.db $08, %0101, $a8, %0101
.db $08, %0110, $02, %0100
.db $08, %0111, $a2, %0101
.db $08, %1000, $08, %0000
.db $08, %1001, $68, %0001
.db $08, %1010, $0e, %0000
.db $08, %1011, $6e, %0001
.db $08, %1100, $08, %0100
.db $08, %1101, $a8, %0101
.db $08, %1110, $02, %0100
.db $08, %1111, $a2, %0101
.db $09, %0000, $09, %0000
.db $09, %0001, $69, %0001
.db $09, %0010, $0f, %0000
.db $09, %0011, $6f, %0001
.db $09, %0100, $09, %0100
.db $09, %0101, $a9, %0101
.db $09, %0110, $03, %0100
.db $09, %0111, $a3, %0101
.db $09, %1000, $09, %0000
.db $09, %1001, $69, %0001
.db $09, %1010, $0f, %0000
.db $09, %1011, $6f, %0001
.db $09, %1100, $09, %0100
.db $09, %1101, $a9, %0101
.db $09, %1110, $03, %0100
.db $09, %1111, $a3, %0101
.db $0a, %0000, $10, %0000
.db $0a, %0001, $70, %0001
.db $0a, %0010, $10, %0000
.db $0a, %0011, $70, %0001
.db $0a, %0100, $0a, %0100
.db $0a, %0101, $aa, %0101
.db $0a, %0110, $04, %0100
.db $0a, %0111, $a4, %0101
.db $0a, %1000, $10, %0000
.db $0a, %1001, $70, %0001
.db $0a, %1010, $10, %0000
.db $0a, %1011, $70, %0001
.db $0a, %1100, $0a, %0100
.db $0a, %1101, $aa, %0101
.db $0a, %1110, $04, %0100
.db $0a, %1111, $a4, %0101
.db $0b, %0000, $11, %0000
.db $0b, %0001, $71, %0001
.db $0b, %0010, $11, %0000
.db $0b, %0011, $71, %0001
.db $0b, %0100, $0b, %0100
.db $0b, %0101, $ab, %0101
.db $0b, %0110, $05, %0100
.db $0b, %0111, $a5, %0101
.db $0b, %1000, $11, %0000
.db $0b, %1001, $71, %0001
.db $0b, %1010, $11, %0000
.db $0b, %1011, $71, %0001
.db $0b, %1100, $0b, %0100
.db $0b, %1101, $ab, %0101
.db $0b, %1110, $05, %0100
.db $0b, %1111, $a5, %0101
.db $0c, %0000, $12, %0000
.db $0c, %0001, $72, %0001
.db $0c, %0010, $12, %0000
.db $0c, %0011, $72, %0001
.db $0c, %0100, $0c, %0100
.db $0c, %0101, $ac, %0101
.db $0c, %0110, $06, %0100
.db $0c, %0111, $a6, %0101
.db $0c, %1000, $12, %0000
.db $0c, %1001, $72, %0001
.db $0c, %1010, $12, %0000
.db $0c, %1011, $72, %0001
.db $0c, %1100, $0c, %0100
.db $0c, %1101, $ac, %0101
.db $0c, %1110, $06, %0100
.db $0c, %1111, $a6, %0101
.db $0d, %0000, $13, %0000
.db $0d, %0001, $73, %0001
.db $0d, %0010, $13, %0000
.db $0d, %0011, $73, %0001
.db $0d, %0100, $0d, %0100
.db $0d, %0101, $ad, %0101
.db $0d, %0110, $07, %0100
.db $0d, %0111, $a7, %0101
.db $0d, %1000, $13, %0000
.db $0d, %1001, $73, %0001
.db $0d, %1010, $13, %0000
.db $0d, %1011, $73, %0001
.db $0d, %1100, $0d, %0100
.db $0d, %1101, $ad, %0101
.db $0d, %1110, $07, %0100
.db $0d, %1111, $a7, %0101
.db $0e, %0000, $14, %0000
.db $0e, %0001, $74, %0001
.db $0e, %0010, $14, %0000
.db $0e, %0011, $74, %0001
.db $0e, %0100, $0e, %0100
.db $0e, %0101, $ae, %0101
.db $0e, %0110, $08, %0100
.db $0e, %0111, $a8, %0101
.db $0e, %1000, $14, %0000
.db $0e, %1001, $74, %0001
.db $0e, %1010, $14, %0000
.db $0e, %1011, $74, %0001
.db $0e, %1100, $0e, %0100
.db $0e, %1101, $ae, %0101
.db $0e, %1110, $08, %0100
.db $0e, %1111, $a8, %0101
.db $0f, %0000, $15, %0000
.db $0f, %0001, $75, %0001
.db $0f, %0010, $15, %0000
.db $0f, %0011, $75, %0001
.db $0f, %0100, $0f, %0100
.db $0f, %0101, $af, %0101
.db $0f, %0110, $09, %0100
.db $0f, %0111, $a9, %0101
.db $0f, %1000, $15, %0000
.db $0f, %1001, $75, %0001
.db $0f, %1010, $15, %0000
.db $0f, %1011, $75, %0001
.db $0f, %1100, $0f, %0100
.db $0f, %1101, $af, %0101
.db $0f, %1110, $09, %0100
.db $0f, %1111, $a9, %0101
.db $10, %0000, $10, %0000
.db $10, %0001, $70, %0001
.db $10, %0010, $16, %0000
.db $10, %0011, $76, %0001
.db $10, %0100, $10, %0100
.db $10, %0101, $b0, %0101
.db $10, %0110, $0a, %0100
.db $10, %0111, $aa, %0101
.db $10, %1000, $10, %0000
.db $10, %1001, $70, %0001
.db $10, %1010, $16, %0000
.db $10, %1011, $76, %0001
.db $10, %1100, $10, %0100
.db $10, %1101, $b0, %0101
.db $10, %1110, $0a, %0100
.db $10, %1111, $aa, %0101
.db $11, %0000, $11, %0000
.db $11, %0001, $71, %0001
.db $11, %0010, $17, %0000
.db $11, %0011, $77, %0001
.db $11, %0100, $11, %0100
.db $11, %0101, $b1, %0101
.db $11, %0110, $0b, %0100
.db $11, %0111, $ab, %0101
.db $11, %1000, $11, %0000
.db $11, %1001, $71, %0001
.db $11, %1010, $17, %0000
.db $11, %1011, $77, %0001
.db $11, %1100, $11, %0100
.db $11, %1101, $b1, %0101
.db $11, %1110, $0b, %0100
.db $11, %1111, $ab, %0101
.db $12, %0000, $12, %0000
.db $12, %0001, $72, %0001
.db $12, %0010, $18, %0000
.db $12, %0011, $78, %0001
.db $12, %0100, $12, %0100
.db $12, %0101, $b2, %0101
.db $12, %0110, $0c, %0100
.db $12, %0111, $ac, %0101
.db $12, %1000, $12, %0000
.db $12, %1001, $72, %0001
.db $12, %1010, $18, %0000
.db $12, %1011, $78, %0001
.db $12, %1100, $12, %0100
.db $12, %1101, $b2, %0101
.db $12, %1110, $0c, %0100
.db $12, %1111, $ac, %0101
.db $13, %0000, $13, %0000
.db $13, %0001, $73, %0001
.db $13, %0010, $19, %0000
.db $13, %0011, $79, %0001
.db $13, %0100, $13, %0100
.db $13, %0101, $b3, %0101
.db $13, %0110, $0d, %0100
.db $13, %0111, $ad, %0101
.db $13, %1000, $13, %0000
.db $13, %1001, $73, %0001
.db $13, %1010, $19, %0000
.db $13, %1011, $79, %0001
.db $13, %1100, $13, %0100
.db $13, %1101, $b3, %0101
.db $13, %1110, $0d, %0100
.db $13, %1111, $ad, %0101
.db $14, %0000, $14, %0000
.db $14, %0001, $74, %0001
.db $14, %0010, $1a, %0000
.db $14, %0011, $7a, %0001
.db $14, %0100, $14, %0100
.db $14, %0101, $b4, %0101
.db $14, %0110, $0e, %0100
.db $14, %0111, $ae, %0101
.db $14, %1000, $14, %0000
.db $14, %1001, $74, %0001
.db $14, %1010, $1a, %0000
.db $14, %1011, $7a, %0001
.db $14, %1100, $14, %0100
.db $14, %1101, $b4, %0101
.db $14, %1110, $0e, %0100
.db $14, %1111, $ae, %0101
.db $15, %0000, $15, %0000
.db $15, %0001, $75, %0001
.db $15, %0010, $1b, %0000
.db $15, %0011, $7b, %0001
.db $15, %0100, $15, %0100
.db $15, %0101, $b5, %0101
.db $15, %0110, $0f, %0100
.db $15, %0111, $af, %0101
.db $15, %1000, $15, %0000
.db $15, %1001, $75, %0001
.db $15, %1010, $1b, %0000
.db $15, %1011, $7b, %0001
.db $15, %1100, $15, %0100
.db $15, %1101, $b5, %0101
.db $15, %1110, $0f, %0100
.db $15, %1111, $af, %0101
.db $16, %0000, $16, %0000
.db $16, %0001, $76, %0001
.db $16, %0010, $1c, %0000
.db $16, %0011, $7c, %0001
.db $16, %0100, $16, %0100
.db $16, %0101, $b6, %0101
.db $16, %0110, $10, %0100
.db $16, %0111, $b0, %0101
.db $16, %1000, $16, %0000
.db $16, %1001, $76, %0001
.db $16, %1010, $1c, %0000
.db $16, %1011, $7c, %0001
.db $16, %1100, $16, %0100
.db $16, %1101, $b6, %0101
.db $16, %1110, $10, %0100
.db $16, %1111, $b0, %0101
.db $17, %0000, $17, %0000
.db $17, %0001, $77, %0001
.db $17, %0010, $1d, %0000
.db $17, %0011, $7d, %0001
.db $17, %0100, $17, %0100
.db $17, %0101, $b7, %0101
.db $17, %0110, $11, %0100
.db $17, %0111, $b1, %0101
.db $17, %1000, $17, %0000
.db $17, %1001, $77, %0001
.db $17, %1010, $1d, %0000
.db $17, %1011, $7d, %0001
.db $17, %1100, $17, %0100
.db $17, %1101, $b7, %0101
.db $17, %1110, $11, %0100
.db $17, %1111, $b1, %0101
.db $18, %0000, $18, %0000
.db $18, %0001, $78, %0001
.db $18, %0010, $1e, %0000
.db $18, %0011, $7e, %0001
.db $18, %0100, $18, %0100
.db $18, %0101, $b8, %0101
.db $18, %0110, $12, %0100
.db $18, %0111, $b2, %0101
.db $18, %1000, $18, %0000
.db $18, %1001, $78, %0001
.db $18, %1010, $1e, %0000
.db $18, %1011, $7e, %0001
.db $18, %1100, $18, %0100
.db $18, %1101, $b8, %0101
.db $18, %1110, $12, %0100
.db $18, %1111, $b2, %0101
.db $19, %0000, $19, %0000
.db $19, %0001, $79, %0001
.db $19, %0010, $1f, %0000
.db $19, %0011, $7f, %0001
.db $19, %0100, $19, %0100
.db $19, %0101, $b9, %0101
.db $19, %0110, $13, %0100
.db $19, %0111, $b3, %0101
.db $19, %1000, $19, %0000
.db $19, %1001, $79, %0001
.db $19, %1010, $1f, %0000
.db $19, %1011, $7f, %0001
.db $19, %1100, $19, %0100
.db $19, %1101, $b9, %0101
.db $19, %1110, $13, %0100
.db $19, %1111, $b3, %0101
.db $1a, %0000, $20, %0000
.db $1a, %0001, $80, %0001
.db $1a, %0010, $20, %0000
.db $1a, %0011, $80, %0001
.db $1a, %0100, $1a, %0100
.db $1a, %0101, $ba, %0101
.db $1a, %0110, $14, %0100
.db $1a, %0111, $b4, %0101
.db $1a, %1000, $20, %0000
.db $1a, %1001, $80, %0001
.db $1a, %1010, $20, %0000
.db $1a, %1011, $80, %0001
.db $1a, %1100, $1a, %0100
.db $1a, %1101, $ba, %0101
.db $1a, %1110, $14, %0100
.db $1a, %1111, $b4, %0101
.db $1b, %0000, $21, %0000
.db $1b, %0001, $81, %0001
.db $1b, %0010, $21, %0000
.db $1b, %0011, $81, %0001
.db $1b, %0100, $1b, %0100
.db $1b, %0101, $bb, %0101
.db $1b, %0110, $15, %0100
.db $1b, %0111, $b5, %0101
.db $1b, %1000, $21, %0000
.db $1b, %1001, $81, %0001
.db $1b, %1010, $21, %0000
.db $1b, %1011, $81, %0001
.db $1b, %1100, $1b, %0100
.db $1b, %1101, $bb, %0101
.db $1b, %1110, $15, %0100
.db $1b, %1111, $b5, %0101
.db $1c, %0000, $22, %0000
.db $1c, %0001, $82, %0001
.db $1c, %0010, $22, %0000
.db $1c, %0011, $82, %0001
.db $1c, %0100, $1c, %0100
.db $1c, %0101, $bc, %0101
.db $1c, %0110, $16, %0100
.db $1c, %0111, $b6, %0101
.db $1c, %1000, $22, %0000
.db $1c, %1001, $82, %0001
.db $1c, %1010, $22, %0000
.db $1c, %1011, $82, %0001
.db $1c, %1100, $1c, %0100
.db $1c, %1101, $bc, %0101
.db $1c, %1110, $16, %0100
.db $1c, %1111, $b6, %0101
.db $1d, %0000, $23, %0000
.db $1d, %0001, $83, %0001
.db $1d, %0010, $23, %0000
.db $1d, %0011, $83, %0001
.db $1d, %0100, $1d, %0100
.db $1d, %0101, $bd, %0101
.db $1d, %0110, $17, %0100
.db $1d, %0111, $b7, %0101
.db $1d, %1000, $23, %0000
.db $1d, %1001, $83, %0001
.db $1d, %1010, $23, %0000
.db $1d, %1011, $83, %0001
.db $1d, %1100, $1d, %0100
.db $1d, %1101, $bd, %0101
.db $1d, %1110, $17, %0100
.db $1d, %1111, $b7, %0101
.db $1e, %0000, $24, %0000
.db $1e, %0001, $84, %0001
.db $1e, %0010, $24, %0000
.db $1e, %0011, $84, %0001
.db $1e, %0100, $1e, %0100
.db $1e, %0101, $be, %0101
.db $1e, %0110, $18, %0100
.db $1e, %0111, $b8, %0101
.db $1e, %1000, $24, %0000
.db $1e, %1001, $84, %0001
.db $1e, %1010, $24, %0000
.db $1e, %1011, $84, %0001
.db $1e, %1100, $1e, %0100
.db $1e, %1101, $be, %0101
.db $1e, %1110, $18, %0100
.db $1e, %1111, $b8, %0101
.db $1f, %0000, $25, %0000
.db $1f, %0001, $85, %0001
.db $1f, %0010, $25, %0000
.db $1f, %0011, $85, %0001
.db $1f, %0100, $1f, %0100
.db $1f, %0101, $bf, %0101
.db $1f, %0110, $19, %0100
.db $1f, %0111, $b9, %0101
.db $1f, %1000, $25, %0000
.db $1f, %1001, $85, %0001
.db $1f, %1010, $25, %0000
.db $1f, %1011, $85, %0001
.db $1f, %1100, $1f, %0100
.db $1f, %1101, $bf, %0101
.db $1f, %1110, $19, %0100
.db $1f, %1111, $b9, %0101
.db $20, %0000, $20, %0000
.db $20, %0001, $80, %0001
.db $20, %0010, $26, %0000
.db $20, %0011, $86, %0001
.db $20, %0100, $20, %0100
.db $20, %0101, $c0, %0101
.db $20, %0110, $1a, %0100
.db $20, %0111, $ba, %0101
.db $20, %1000, $20, %0000
.db $20, %1001, $80, %0001
.db $20, %1010, $26, %0000
.db $20, %1011, $86, %0001
.db $20, %1100, $20, %0100
.db $20, %1101, $c0, %0101
.db $20, %1110, $1a, %0100
.db $20, %1111, $ba, %0101
.db $21, %0000, $21, %0000
.db $21, %0001, $81, %0001
.db $21, %0010, $27, %0000
.db $21, %0011, $87, %0001
.db $21, %0100, $21, %0100
.db $21, %0101, $c1, %0101
.db $21, %0110, $1b, %0100
.db $21, %0111, $bb, %0101
.db $21, %1000, $21, %0000
.db $21, %1001, $81, %0001
.db $21, %1010, $27, %0000
.db $21, %1011, $87, %0001
.db $21, %1100, $21, %0100
.db $21, %1101, $c1, %0101
.db $21, %1110, $1b, %0100
.db $21, %1111, $bb, %0101
.db $22, %0000, $22, %0000
.db $22, %0001, $82, %0001
.db $22, %0010, $28, %0000
.db $22, %0011, $88, %0001
.db $22, %0100, $22, %0100
.db $22, %0101, $c2, %0101
.db $22, %0110, $1c, %0100
.db $22, %0111, $bc, %0101
.db $22, %1000, $22, %0000
.db $22, %1001, $82, %0001
.db $22, %1010, $28, %0000
.db $22, %1011, $88, %0001
.db $22, %1100, $22, %0100
.db $22, %1101, $c2, %0101
.db $22, %1110, $1c, %0100
.db $22, %1111, $bc, %0101
.db $23, %0000, $23, %0000
.db $23, %0001, $83, %0001
.db $23, %0010, $29, %0000
.db $23, %0011, $89, %0001
.db $23, %0100, $23, %0100
.db $23, %0101, $c3, %0101
.db $23, %0110, $1d, %0100
.db $23, %0111, $bd, %0101
.db $23, %1000, $23, %0000
.db $23, %1001, $83, %0001
.db $23, %1010, $29, %0000
.db $23, %1011, $89, %0001
.db $23, %1100, $23, %0100
.db $23, %1101, $c3, %0101
.db $23, %1110, $1d, %0100
.db $23, %1111, $bd, %0101
.db $24, %0000, $24, %0000
.db $24, %0001, $84, %0001
.db $24, %0010, $2a, %0000
.db $24, %0011, $8a, %0001
.db $24, %0100, $24, %0100
.db $24, %0101, $c4, %0101
.db $24, %0110, $1e, %0100
.db $24, %0111, $be, %0101
.db $24, %1000, $24, %0000
.db $24, %1001, $84, %0001
.db $24, %1010, $2a, %0000
.db $24, %1011, $8a, %0001
.db $24, %1100, $24, %0100
.db $24, %1101, $c4, %0101
.db $24, %1110, $1e, %0100
.db $24, %1111, $be, %0101
.db $25, %0000, $25, %0000
.db $25, %0001, $85, %0001
.db $25, %0010, $2b, %0000
.db $25, %0011, $8b, %0001
.db $25, %0100, $25, %0100
.db $25, %0101, $c5, %0101
.db $25, %0110, $1f, %0100
.db $25, %0111, $bf, %0101
.db $25, %1000, $25, %0000
.db $25, %1001, $85, %0001
.db $25, %1010, $2b, %0000
.db $25, %1011, $8b, %0001
.db $25, %1100, $25, %0100
.db $25, %1101, $c5, %0101
.db $25, %1110, $1f, %0100
.db $25, %1111, $bf, %0101
.db $26, %0000, $26, %0000
.db $26, %0001, $86, %0001
.db $26, %0010, $2c, %0000
.db $26, %0011, $8c, %0001
.db $26, %0100, $26, %0100
.db $26, %0101, $c6, %0101
.db $26, %0110, $20, %0100
.db $26, %0111, $c0, %0101
.db $26, %1000, $26, %0000
.db $26, %1001, $86, %0001
.db $26, %1010, $2c, %0000
.db $26, %1011, $8c, %0001
.db $26, %1100, $26, %0100
.db $26, %1101, $c6, %0101
.db $26, %1110, $20, %0100
.db $26, %1111, $c0, %0101
.db $27, %0000, $27, %0000
.db $27, %0001, $87, %0001
.db $27, %0010, $2d, %0000
.db $27, %0011, $8d, %0001
.db $27, %0100, $27, %0100
.db $27, %0101, $c7, %0101
.db $27, %0110, $21, %0100
.db $27, %0111, $c1, %0101
.db $27, %1000, $27, %0000
.db $27, %1001, $87, %0001
.db $27, %1010, $2d, %0000
.db $27, %1011, $8d, %0001
.db $27, %1100, $27, %0100
.db $27, %1101, $c7, %0101
.db $27, %1110, $21, %0100
.db $27, %1111, $c1, %0101
.db $28, %0000, $28, %0000
.db $28, %0001, $88, %0001
.db $28, %0010, $2e, %0000
.db $28, %0011, $8e, %0001
.db $28, %0100, $28, %0100
.db $28, %0101, $c8, %0101
.db $28, %0110, $22, %0100
.db $28, %0111, $c2, %0101
.db $28, %1000, $28, %0000
.db $28, %1001, $88, %0001
.db $28, %1010, $2e, %0000
.db $28, %1011, $8e, %0001
.db $28, %1100, $28, %0100
.db $28, %1101, $c8, %0101
.db $28, %1110, $22, %0100
.db $28, %1111, $c2, %0101
.db $29, %0000, $29, %0000
.db $29, %0001, $89, %0001
.db $29, %0010, $2f, %0000
.db $29, %0011, $8f, %0001
.db $29, %0100, $29, %0100
.db $29, %0101, $c9, %0101
.db $29, %0110, $23, %0100
.db $29, %0111, $c3, %0101
.db $29, %1000, $29, %0000
.db $29, %1001, $89, %0001
.db $29, %1010, $2f, %0000
.db $29, %1011, $8f, %0001
.db $29, %1100, $29, %0100
.db $29, %1101, $c9, %0101
.db $29, %1110, $23, %0100
.db $29, %1111, $c3, %0101
.db $2a, %0000, $30, %0000
.db $2a, %0001, $90, %0001
.db $2a, %0010, $30, %0000
.db $2a, %0011, $90, %0001
.db $2a, %0100, $2a, %0100
.db $2a, %0101, $ca, %0101
.db $2a, %0110, $24, %0100
.db $2a, %0111, $c4, %0101
.db $2a, %1000, $30, %0000
.db $2a, %1001, $90, %0001
.db $2a, %1010, $30, %0000
.db $2a, %1011, $90, %0001
.db $2a, %1100, $2a, %0100
.db $2a, %1101, $ca, %0101
.db $2a, %1110, $24, %0100
.db $2a, %1111, $c4, %0101
.db $2b, %0000, $31, %0000
.db $2b, %0001, $91, %0001
.db $2b, %0010, $31, %0000
.db $2b, %0011, $91, %0001
.db $2b, %0100, $2b, %0100
.db $2b, %0101, $cb, %0101
.db $2b, %0110, $25, %0100
.db $2b, %0111, $c5, %0101
.db $2b, %1000, $31, %0000
.db $2b, %1001, $91, %0001
.db $2b, %1010, $31, %0000
.db $2b, %1011, $91, %0001
.db $2b, %1100, $2b, %0100
.db $2b, %1101, $cb, %0101
.db $2b, %1110, $25, %0100
.db $2b, %1111, $c5, %0101
.db $2c, %0000, $32, %0000
.db $2c, %0001, $92, %0001
.db $2c, %0010, $32, %0000
.db $2c, %0011, $92, %0001
.db $2c, %0100, $2c, %0100
.db $2c, %0101, $cc, %0101
.db $2c, %0110, $26, %0100
.db $2c, %0111, $c6, %0101
.db $2c, %1000, $32, %0000
.db $2c, %1001, $92, %0001
.db $2c, %1010, $32, %0000
.db $2c, %1011, $92, %0001
.db $2c, %1100, $2c, %0100
.db $2c, %1101, $cc, %0101
.db $2c, %1110, $26, %0100
.db $2c, %1111, $c6, %0101
.db $2d, %0000, $33, %0000
.db $2d, %0001, $93, %0001
.db $2d, %0010, $33, %0000
.db $2d, %0011, $93, %0001
.db $2d, %0100, $2d, %0100
.db $2d, %0101, $cd, %0101
.db $2d, %0110, $27, %0100
.db $2d, %0111, $c7, %0101
.db $2d, %1000, $33, %0000
.db $2d, %1001, $93, %0001
.db $2d, %1010, $33, %0000
.db $2d, %1011, $93, %0001
.db $2d, %1100, $2d, %0100
.db $2d, %1101, $cd, %0101
.db $2d, %1110, $27, %0100
.db $2d, %1111, $c7, %0101
.db $2e, %0000, $34, %0000
.db $2e, %0001, $94, %0001
.db $2e, %0010, $34, %0000
.db $2e, %0011, $94, %0001
.db $2e, %0100, $2e, %0100
.db $2e, %0101, $ce, %0101
.db $2e, %0110, $28, %0100
.db $2e, %0111, $c8, %0101
.db $2e, %1000, $34, %0000
.db $2e, %1001, $94, %0001
.db $2e, %1010, $34, %0000
.db $2e, %1011, $94, %0001
.db $2e, %1100, $2e, %0100
.db $2e, %1101, $ce, %0101
.db $2e, %1110, $28, %0100
.db $2e, %1111, $c8, %0101
.db $2f, %0000, $35, %0000
.db $2f, %0001, $95, %0001
.db $2f, %0010, $35, %0000
.db $2f, %0011, $95, %0001
.db $2f, %0100, $2f, %0100
.db $2f, %0101, $cf, %0101
.db $2f, %0110, $29, %0100
.db $2f, %0111, $c9, %0101
.db $2f, %1000, $35, %0000
.db $2f, %1001, $95, %0001
.db $2f, %1010, $35, %0000
.db $2f, %1011, $95, %0001
.db $2f, %1100, $2f, %0100
.db $2f, %1101, $cf, %0101
.db $2f, %1110, $29, %0100
.db $2f, %1111, $c9, %0101
.db $30, %0000, $30, %0000
.db $30, %0001, $90, %0001
.db $30, %0010, $36, %0000
.db $30, %0011, $96, %0001
.db $30, %0100, $30, %0100
.db $30, %0101, $d0, %0101
.db $30, %0110, $2a, %0100
.db $30, %0111, $ca, %0101
.db $30, %1000, $30, %0000
.db $30, %1001, $90, %0001
.db $30, %1010, $36, %0000
.db $30, %1011, $96, %0001
.db $30, %1100, $30, %0100
.db $30, %1101, $d0, %0101
.db $30, %1110, $2a, %0100
.db $30, %1111, $ca, %0101
.db $31, %0000, $31, %0000
.db $31, %0001, $91, %0001
.db $31, %0010, $37, %0000
.db $31, %0011, $97, %0001
.db $31, %0100, $31, %0100
.db $31, %0101, $d1, %0101
.db $31, %0110, $2b, %0100
.db $31, %0111, $cb, %0101
.db $31, %1000, $31, %0000
.db $31, %1001, $91, %0001
.db $31, %1010, $37, %0000
.db $31, %1011, $97, %0001
.db $31, %1100, $31, %0100
.db $31, %1101, $d1, %0101
.db $31, %1110, $2b, %0100
.db $31, %1111, $cb, %0101
.db $32, %0000, $32, %0000
.db $32, %0001, $92, %0001
.db $32, %0010, $38, %0000
.db $32, %0011, $98, %0001
.db $32, %0100, $32, %0100
.db $32, %0101, $d2, %0101
.db $32, %0110, $2c, %0100
.db $32, %0111, $cc, %0101
.db $32, %1000, $32, %0000
.db $32, %1001, $92, %0001
.db $32, %1010, $38, %0000
.db $32, %1011, $98, %0001
.db $32, %1100, $32, %0100
.db $32, %1101, $d2, %0101
.db $32, %1110, $2c, %0100
.db $32, %1111, $cc, %0101
.db $33, %0000, $33, %0000
.db $33, %0001, $93, %0001
.db $33, %0010, $39, %0000
.db $33, %0011, $99, %0001
.db $33, %0100, $33, %0100
.db $33, %0101, $d3, %0101
.db $33, %0110, $2d, %0100
.db $33, %0111, $cd, %0101
.db $33, %1000, $33, %0000
.db $33, %1001, $93, %0001
.db $33, %1010, $39, %0000
.db $33, %1011, $99, %0001
.db $33, %1100, $33, %0100
.db $33, %1101, $d3, %0101
.db $33, %1110, $2d, %0100
.db $33, %1111, $cd, %0101
.db $34, %0000, $34, %0000
.db $34, %0001, $94, %0001
.db $34, %0010, $3a, %0000
.db $34, %0011, $9a, %0001
.db $34, %0100, $34, %0100
.db $34, %0101, $d4, %0101
.db $34, %0110, $2e, %0100
.db $34, %0111, $ce, %0101
.db $34, %1000, $34, %0000
.db $34, %1001, $94, %0001
.db $34, %1010, $3a, %0000
.db $34, %1011, $9a, %0001
.db $34, %1100, $34, %0100
.db $34, %1101, $d4, %0101
.db $34, %1110, $2e, %0100
.db $34, %1111, $ce, %0101
.db $35, %0000, $35, %0000
.db $35, %0001, $95, %0001
.db $35, %0010, $3b, %0000
.db $35, %0011, $9b, %0001
.db $35, %0100, $35, %0100
.db $35, %0101, $d5, %0101
.db $35, %0110, $2f, %0100
.db $35, %0111, $cf, %0101
.db $35, %1000, $35, %0000
.db $35, %1001, $95, %0001
.db $35, %1010, $3b, %0000
.db $35, %1011, $9b, %0001
.db $35, %1100, $35, %0100
.db $35, %1101, $d5, %0101
.db $35, %1110, $2f, %0100
.db $35, %1111, $cf, %0101
.db $36, %0000, $36, %0000
.db $36, %0001, $96, %0001
.db $36, %0010, $3c, %0000
.db $36, %0011, $9c, %0001
.db $36, %0100, $36, %0100
.db $36, %0101, $d6, %0101
.db $36, %0110, $30, %0100
.db $36, %0111, $d0, %0101
.db $36, %1000, $36, %0000
.db $36, %1001, $96, %0001
.db $36, %1010, $3c, %0000
.db $36, %1011, $9c, %0001
.db $36, %1100, $36, %0100
.db $36, %1101, $d6, %0101
.db $36, %1110, $30, %0100
.db $36, %1111, $d0, %0101
.db $37, %0000, $37, %0000
.db $37, %0001, $97, %0001
.db $37, %0010, $3d, %0000
.db $37, %0011, $9d, %0001
.db $37, %0100, $37, %0100
.db $37, %0101, $d7, %0101
.db $37, %0110, $31, %0100
.db $37, %0111, $d1, %0101
.db $37, %1000, $37, %0000
.db $37, %1001, $97, %0001
.db $37, %1010, $3d, %0000
.db $37, %1011, $9d, %0001
.db $37, %1100, $37, %0100
.db $37, %1101, $d7, %0101
.db $37, %1110, $31, %0100
.db $37, %1111, $d1, %0101
.db $38, %0000, $38, %0000
.db $38, %0001, $98, %0001
.db $38, %0010, $3e, %0000
.db $38, %0011, $9e, %0001
.db $38, %0100, $38, %0100
.db $38, %0101, $d8, %0101
.db $38, %0110, $32, %0100
.db $38, %0111, $d2, %0101
.db $38, %1000, $38, %0000
.db $38, %1001, $98, %0001
.db $38, %1010, $3e, %0000
.db $38, %1011, $9e, %0001
.db $38, %1100, $38, %0100
.db $38, %1101, $d8, %0101
.db $38, %1110, $32, %0100
.db $38, %1111, $d2, %0101
.db $39, %0000, $39, %0000
.db $39, %0001, $99, %0001
.db $39, %0010, $3f, %0000
.db $39, %0011, $9f, %0001
.db $39, %0100, $39, %0100
.db $39, %0101, $d9, %0101
.db $39, %0110, $33, %0100
.db $39, %0111, $d3, %0101
.db $39, %1000, $39, %0000
.db $39, %1001, $99, %0001
.db $39, %1010, $3f, %0000
.db $39, %1011, $9f, %0001
.db $39, %1100, $39, %0100
.db $39, %1101, $d9, %0101
.db $39, %1110, $33, %0100
.db $39, %1111, $d3, %0101
.db $3a, %0000, $40, %0000
.db $3a, %0001, $a0, %0001
.db $3a, %0010, $40, %0000
.db $3a, %0011, $a0, %0001
.db $3a, %0100, $3a, %0100
.db $3a, %0101, $da, %0101
.db $3a, %0110, $34, %0100
.db $3a, %0111, $d4, %0101
.db $3a, %1000, $40, %0000
.db $3a, %1001, $a0, %0001
.db $3a, %1010, $40, %0000
.db $3a, %1011, $a0, %0001
.db $3a, %1100, $3a, %0100
.db $3a, %1101, $da, %0101
.db $3a, %1110, $34, %0100
.db $3a, %1111, $d4, %0101
.db $3b, %0000, $41, %0000
.db $3b, %0001, $a1, %0001
.db $3b, %0010, $41, %0000
.db $3b, %0011, $a1, %0001
.db $3b, %0100, $3b, %0100
.db $3b, %0101, $db, %0101
.db $3b, %0110, $35, %0100
.db $3b, %0111, $d5, %0101
.db $3b, %1000, $41, %0000
.db $3b, %1001, $a1, %0001
.db $3b, %1010, $41, %0000
.db $3b, %1011, $a1, %0001
.db $3b, %1100, $3b, %0100
.db $3b, %1101, $db, %0101
.db $3b, %1110, $35, %0100
.db $3b, %1111, $d5, %0101
.db $3c, %0000, $42, %0000
.db $3c, %0001, $a2, %0001
.db $3c, %0010, $42, %0000
.db $3c, %0011, $a2, %0001
.db $3c, %0100, $3c, %0100
.db $3c, %0101, $dc, %0101
.db $3c, %0110, $36, %0100
.db $3c, %0111, $d6, %0101
.db $3c, %1000, $42, %0000
.db $3c, %1001, $a2, %0001
.db $3c, %1010, $42, %0000
.db $3c, %1011, $a2, %0001
.db $3c, %1100, $3c, %0100
.db $3c, %1101, $dc, %0101
.db $3c, %1110, $36, %0100
.db $3c, %1111, $d6, %0101
.db $3d, %0000, $43, %0000
.db $3d, %0001, $a3, %0001
.db $3d, %0010, $43, %0000
.db $3d, %0011, $a3, %0001
.db $3d, %0100, $3d, %0100
.db $3d, %0101, $dd, %0101
.db $3d, %0110, $37, %0100
.db $3d, %0111, $d7, %0101
.db $3d, %1000, $43, %0000
.db $3d, %1001, $a3, %0001
.db $3d, %1010, $43, %0000
.db $3d, %1011, $a3, %0001
.db $3d, %1100, $3d, %0100
.db $3d, %1101, $dd, %0101
.db $3d, %1110, $37, %0100
.db $3d, %1111, $d7, %0101
.db $3e, %0000, $44, %0000
.db $3e, %0001, $a4, %0001
.db $3e, %0010, $44, %0000
.db $3e, %0011, $a4, %0001
.db $3e, %0100, $3e, %0100
.db $3e, %0101, $de, %0101
.db $3e, %0110, $38, %0100
.db $3e, %0111, $d8, %0101
.db $3e, %1000, $44, %0000
.db $3e, %1001, $a4, %0001
.db $3e, %1010, $44, %0000
.db $3e, %1011, $a4, %0001
.db $3e, %1100, $3e, %0100
.db $3e, %1101, $de, %0101
.db $3e, %1110, $38, %0100
.db $3e, %1111, $d8, %0101
.db $3f, %0000, $45, %0000
.db $3f, %0001, $a5, %0001
.db $3f, %0010, $45, %0000
.db $3f, %0011, $a5, %0001
.db $3f, %0100, $3f, %0100
.db $3f, %0101, $df, %0101
.db $3f, %0110, $39, %0100
.db $3f, %0111, $d9, %0101
.db $3f, %1000, $45, %0000
.db $3f, %1001, $a5, %0001
.db $3f, %1010, $45, %0000
.db $3f, %1011, $a5, %0001
.db $3f, %1100, $3f, %0100
.db $3f, %1101, $df, %0101
.db $3f, %1110, $39, %0100
.db $3f, %1111, $d9, %0101
.db $40, %0000, $40, %0000
.db $40, %0001, $a0, %0001
.db $40, %0010, $46, %0000
.db $40, %0011, $a6, %0001
.db $40, %0100, $40, %0100
.db $40, %0101, $e0, %0101
.db $40, %0110, $3a, %0100
.db $40, %0111, $da, %0101
.db $40, %1000, $40, %0000
.db $40, %1001, $a0, %0001
.db $40, %1010, $46, %0000
.db $40, %1011, $a6, %0001
.db $40, %1100, $40, %0100
.db $40, %1101, $e0, %0101
.db $40, %1110, $3a, %0100
.db $40, %1111, $da, %0101
.db $41, %0000, $41, %0000
.db $41, %0001, $a1, %0001
.db $41, %0010, $47, %0000
.db $41, %0011, $a7, %0001
.db $41, %0100, $41, %0100
.db $41, %0101, $e1, %0101
.db $41, %0110, $3b, %0100
.db $41, %0111, $db, %0101
.db $41, %1000, $41, %0000
.db $41, %1001, $a1, %0001
.db $41, %1010, $47, %0000
.db $41, %1011, $a7, %0001
.db $41, %1100, $41, %0100
.db $41, %1101, $e1, %0101
.db $41, %1110, $3b, %0100
.db $41, %1111, $db, %0101
.db $42, %0000, $42, %0000
.db $42, %0001, $a2, %0001
.db $42, %0010, $48, %0000
.db $42, %0011, $a8, %0001
.db $42, %0100, $42, %0100
.db $42, %0101, $e2, %0101
.db $42, %0110, $3c, %0100
.db $42, %0111, $dc, %0101
.db $42, %1000, $42, %0000
.db $42, %1001, $a2, %0001
.db $42, %1010, $48, %0000
.db $42, %1011, $a8, %0001
.db $42, %1100, $42, %0100
.db $42, %1101, $e2, %0101
.db $42, %1110, $3c, %0100
.db $42, %1111, $dc, %0101
.db $43, %0000, $43, %0000
.db $43, %0001, $a3, %0001
.db $43, %0010, $49, %0000
.db $43, %0011, $a9, %0001
.db $43, %0100, $43, %0100
.db $43, %0101, $e3, %0101
.db $43, %0110, $3d, %0100
.db $43, %0111, $dd, %0101
.db $43, %1000, $43, %0000
.db $43, %1001, $a3, %0001
.db $43, %1010, $49, %0000
.db $43, %1011, $a9, %0001
.db $43, %1100, $43, %0100
.db $43, %1101, $e3, %0101
.db $43, %1110, $3d, %0100
.db $43, %1111, $dd, %0101
.db $44, %0000, $44, %0000
.db $44, %0001, $a4, %0001
.db $44, %0010, $4a, %0000
.db $44, %0011, $aa, %0001
.db $44, %0100, $44, %0100
.db $44, %0101, $e4, %0101
.db $44, %0110, $3e, %0100
.db $44, %0111, $de, %0101
.db $44, %1000, $44, %0000
.db $44, %1001, $a4, %0001
.db $44, %1010, $4a, %0000
.db $44, %1011, $aa, %0001
.db $44, %1100, $44, %0100
.db $44, %1101, $e4, %0101
.db $44, %1110, $3e, %0100
.db $44, %1111, $de, %0101
.db $45, %0000, $45, %0000
.db $45, %0001, $a5, %0001
.db $45, %0010, $4b, %0000
.db $45, %0011, $ab, %0001
.db $45, %0100, $45, %0100
.db $45, %0101, $e5, %0101
.db $45, %0110, $3f, %0100
.db $45, %0111, $df, %0101
.db $45, %1000, $45, %0000
.db $45, %1001, $a5, %0001
.db $45, %1010, $4b, %0000
.db $45, %1011, $ab, %0001
.db $45, %1100, $45, %0100
.db $45, %1101, $e5, %0101
.db $45, %1110, $3f, %0100
.db $45, %1111, $df, %0101
.db $46, %0000, $46, %0000
.db $46, %0001, $a6, %0001
.db $46, %0010, $4c, %0000
.db $46, %0011, $ac, %0001
.db $46, %0100, $46, %0100
.db $46, %0101, $e6, %0101
.db $46, %0110, $40, %0100
.db $46, %0111, $e0, %0101
.db $46, %1000, $46, %0000
.db $46, %1001, $a6, %0001
.db $46, %1010, $4c, %0000
.db $46, %1011, $ac, %0001
.db $46, %1100, $46, %0100
.db $46, %1101, $e6, %0101
.db $46, %1110, $40, %0100
.db $46, %1111, $e0, %0101
.db $47, %0000, $47, %0000
.db $47, %0001, $a7, %0001
.db $47, %0010, $4d, %0000
.db $47, %0011, $ad, %0001
.db $47, %0100, $47, %0100
.db $47, %0101, $e7, %0101
.db $47, %0110, $41, %0100
.db $47, %0111, $e1, %0101
.db $47, %1000, $47, %0000
.db $47, %1001, $a7, %0001
.db $47, %1010, $4d, %0000
.db $47, %1011, $ad, %0001
.db $47, %1100, $47, %0100
.db $47, %1101, $e7, %0101
.db $47, %1110, $41, %0100
.db $47, %1111, $e1, %0101
.db $48, %0000, $48, %0000
.db $48, %0001, $a8, %0001
.db $48, %0010, $4e, %0000
.db $48, %0011, $ae, %0001
.db $48, %0100, $48, %0100
.db $48, %0101, $e8, %0101
.db $48, %0110, $42, %0100
.db $48, %0111, $e2, %0101
.db $48, %1000, $48, %0000
.db $48, %1001, $a8, %0001
.db $48, %1010, $4e, %0000
.db $48, %1011, $ae, %0001
.db $48, %1100, $48, %0100
.db $48, %1101, $e8, %0101
.db $48, %1110, $42, %0100
.db $48, %1111, $e2, %0101
.db $49, %0000, $49, %0000
.db $49, %0001, $a9, %0001
.db $49, %0010, $4f, %0000
.db $49, %0011, $af, %0001
.db $49, %0100, $49, %0100
.db $49, %0101, $e9, %0101
.db $49, %0110, $43, %0100
.db $49, %0111, $e3, %0101
.db $49, %1000, $49, %0000
.db $49, %1001, $a9, %0001
.db $49, %1010, $4f, %0000
.db $49, %1011, $af, %0001
.db $49, %1100, $49, %0100
.db $49, %1101, $e9, %0101
.db $49, %1110, $43, %0100
.db $49, %1111, $e3, %0101
.db $4a, %0000, $50, %0000
.db $4a, %0001, $b0, %0001
.db $4a, %0010, $50, %0000
.db $4a, %0011, $b0, %0001
.db $4a, %0100, $4a, %0100
.db $4a, %0101, $ea, %0101
.db $4a, %0110, $44, %0100
.db $4a, %0111, $e4, %0101
.db $4a, %1000, $50, %0000
.db $4a, %1001, $b0, %0001
.db $4a, %1010, $50, %0000
.db $4a, %1011, $b0, %0001
.db $4a, %1100, $4a, %0100
.db $4a, %1101, $ea, %0101
.db $4a, %1110, $44, %0100
.db $4a, %1111, $e4, %0101
.db $4b, %0000, $51, %0000
.db $4b, %0001, $b1, %0001
.db $4b, %0010, $51, %0000
.db $4b, %0011, $b1, %0001
.db $4b, %0100, $4b, %0100
.db $4b, %0101, $eb, %0101
.db $4b, %0110, $45, %0100
.db $4b, %0111, $e5, %0101
.db $4b, %1000, $51, %0000
.db $4b, %1001, $b1, %0001
.db $4b, %1010, $51, %0000
.db $4b, %1011, $b1, %0001
.db $4b, %1100, $4b, %0100
.db $4b, %1101, $eb, %0101
.db $4b, %1110, $45, %0100
.db $4b, %1111, $e5, %0101
.db $4c, %0000, $52, %0000
.db $4c, %0001, $b2, %0001
.db $4c, %0010, $52, %0000
.db $4c, %0011, $b2, %0001
.db $4c, %0100, $4c, %0100
.db $4c, %0101, $ec, %0101
.db $4c, %0110, $46, %0100
.db $4c, %0111, $e6, %0101
.db $4c, %1000, $52, %0000
.db $4c, %1001, $b2, %0001
.db $4c, %1010, $52, %0000
.db $4c, %1011, $b2, %0001
.db $4c, %1100, $4c, %0100
.db $4c, %1101, $ec, %0101
.db $4c, %1110, $46, %0100
.db $4c, %1111, $e6, %0101
.db $4d, %0000, $53, %0000
.db $4d, %0001, $b3, %0001
.db $4d, %0010, $53, %0000
.db $4d, %0011, $b3, %0001
.db $4d, %0100, $4d, %0100
.db $4d, %0101, $ed, %0101
.db $4d, %0110, $47, %0100
.db $4d, %0111, $e7, %0101
.db $4d, %1000, $53, %0000
.db $4d, %1001, $b3, %0001
.db $4d, %1010, $53, %0000
.db $4d, %1011, $b3, %0001
.db $4d, %1100, $4d, %0100
.db $4d, %1101, $ed, %0101
.db $4d, %1110, $47, %0100
.db $4d, %1111, $e7, %0101
.db $4e, %0000, $54, %0000
.db $4e, %0001, $b4, %0001
.db $4e, %0010, $54, %0000
.db $4e, %0011, $b4, %0001
.db $4e, %0100, $4e, %0100
.db $4e, %0101, $ee, %0101
.db $4e, %0110, $48, %0100
.db $4e, %0111, $e8, %0101
.db $4e, %1000, $54, %0000
.db $4e, %1001, $b4, %0001
.db $4e, %1010, $54, %0000
.db $4e, %1011, $b4, %0001
.db $4e, %1100, $4e, %0100
.db $4e, %1101, $ee, %0101
.db $4e, %1110, $48, %0100
.db $4e, %1111, $e8, %0101
.db $4f, %0000, $55, %0000
.db $4f, %0001, $b5, %0001
.db $4f, %0010, $55, %0000
.db $4f, %0011, $b5, %0001
.db $4f, %0100, $4f, %0100
.db $4f, %0101, $ef, %0101
.db $4f, %0110, $49, %0100
.db $4f, %0111, $e9, %0101
.db $4f, %1000, $55, %0000
.db $4f, %1001, $b5, %0001
.db $4f, %1010, $55, %0000
.db $4f, %1011, $b5, %0001
.db $4f, %1100, $4f, %0100
.db $4f, %1101, $ef, %0101
.db $4f, %1110, $49, %0100
.db $4f, %1111, $e9, %0101
.db $50, %0000, $50, %0000
.db $50, %0001, $b0, %0001
.db $50, %0010, $56, %0000
.db $50, %0011, $b6, %0001
.db $50, %0100, $50, %0100
.db $50, %0101, $f0, %0101
.db $50, %0110, $4a, %0100
.db $50, %0111, $ea, %0101
.db $50, %1000, $50, %0000
.db $50, %1001, $b0, %0001
.db $50, %1010, $56, %0000
.db $50, %1011, $b6, %0001
.db $50, %1100, $50, %0100
.db $50, %1101, $f0, %0101
.db $50, %1110, $4a, %0100
.db $50, %1111, $ea, %0101
.db $51, %0000, $51, %0000
.db $51, %0001, $b1, %0001
.db $51, %0010, $57, %0000
.db $51, %0011, $b7, %0001
.db $51, %0100, $51, %0100
.db $51, %0101, $f1, %0101
.db $51, %0110, $4b, %0100
.db $51, %0111, $eb, %0101
.db $51, %1000, $51, %0000
.db $51, %1001, $b1, %0001
.db $51, %1010, $57, %0000
.db $51, %1011, $b7, %0001
.db $51, %1100, $51, %0100
.db $51, %1101, $f1, %0101
.db $51, %1110, $4b, %0100
.db $51, %1111, $eb, %0101
.db $52, %0000, $52, %0000
.db $52, %0001, $b2, %0001
.db $52, %0010, $58, %0000
.db $52, %0011, $b8, %0001
.db $52, %0100, $52, %0100
.db $52, %0101, $f2, %0101
.db $52, %0110, $4c, %0100
.db $52, %0111, $ec, %0101
.db $52, %1000, $52, %0000
.db $52, %1001, $b2, %0001
.db $52, %1010, $58, %0000
.db $52, %1011, $b8, %0001
.db $52, %1100, $52, %0100
.db $52, %1101, $f2, %0101
.db $52, %1110, $4c, %0100
.db $52, %1111, $ec, %0101
.db $53, %0000, $53, %0000
.db $53, %0001, $b3, %0001
.db $53, %0010, $59, %0000
.db $53, %0011, $b9, %0001
.db $53, %0100, $53, %0100
.db $53, %0101, $f3, %0101
.db $53, %0110, $4d, %0100
.db $53, %0111, $ed, %0101
.db $53, %1000, $53, %0000
.db $53, %1001, $b3, %0001
.db $53, %1010, $59, %0000
.db $53, %1011, $b9, %0001
.db $53, %1100, $53, %0100
.db $53, %1101, $f3, %0101
.db $53, %1110, $4d, %0100
.db $53, %1111, $ed, %0101
.db $54, %0000, $54, %0000
.db $54, %0001, $b4, %0001
.db $54, %0010, $5a, %0000
.db $54, %0011, $ba, %0001
.db $54, %0100, $54, %0100
.db $54, %0101, $f4, %0101
.db $54, %0110, $4e, %0100
.db $54, %0111, $ee, %0101
.db $54, %1000, $54, %0000
.db $54, %1001, $b4, %0001
.db $54, %1010, $5a, %0000
.db $54, %1011, $ba, %0001
.db $54, %1100, $54, %0100
.db $54, %1101, $f4, %0101
.db $54, %1110, $4e, %0100
.db $54, %1111, $ee, %0101
.db $55, %0000, $55, %0000
.db $55, %0001, $b5, %0001
.db $55, %0010, $5b, %0000
.db $55, %0011, $bb, %0001
.db $55, %0100, $55, %0100
.db $55, %0101, $f5, %0101
.db $55, %0110, $4f, %0100
.db $55, %0111, $ef, %0101
.db $55, %1000, $55, %0000
.db $55, %1001, $b5, %0001
.db $55, %1010, $5b, %0000
.db $55, %1011, $bb, %0001
.db $55, %1100, $55, %0100
.db $55, %1101, $f5, %0101
.db $55, %1110, $4f, %0100
.db $55, %1111, $ef, %0101
.db $56, %0000, $56, %0000
.db $56, %0001, $b6, %0001
.db $56, %0010, $5c, %0000
.db $56, %0011, $bc, %0001
.db $56, %0100, $56, %0100
.db $56, %0101, $f6, %0101
.db $56, %0110, $50, %0100
.db $56, %0111, $f0, %0101
.db $56, %1000, $56, %0000
.db $56, %1001, $b6, %0001
.db $56, %1010, $5c, %0000
.db $56, %1011, $bc, %0001
.db $56, %1100, $56, %0100
.db $56, %1101, $f6, %0101
.db $56, %1110, $50, %0100
.db $56, %1111, $f0, %0101
.db $57, %0000, $57, %0000
.db $57, %0001, $b7, %0001
.db $57, %0010, $5d, %0000
.db $57, %0011, $bd, %0001
.db $57, %0100, $57, %0100
.db $57, %0101, $f7, %0101
.db $57, %0110, $51, %0100
.db $57, %0111, $f1, %0101
.db $57, %1000, $57, %0000
.db $57, %1001, $b7, %0001
.db $57, %1010, $5d, %0000
.db $57, %1011, $bd, %0001
.db $57, %1100, $57, %0100
.db $57, %1101, $f7, %0101
.db $57, %1110, $51, %0100
.db $57, %1111, $f1, %0101
.db $58, %0000, $58, %0000
.db $58, %0001, $b8, %0001
.db $58, %0010, $5e, %0000
.db $58, %0011, $be, %0001
.db $58, %0100, $58, %0100
.db $58, %0101, $f8, %0101
.db $58, %0110, $52, %0100
.db $58, %0111, $f2, %0101
.db $58, %1000, $58, %0000
.db $58, %1001, $b8, %0001
.db $58, %1010, $5e, %0000
.db $58, %1011, $be, %0001
.db $58, %1100, $58, %0100
.db $58, %1101, $f8, %0101
.db $58, %1110, $52, %0100
.db $58, %1111, $f2, %0101
.db $59, %0000, $59, %0000
.db $59, %0001, $b9, %0001
.db $59, %0010, $5f, %0000
.db $59, %0011, $bf, %0001
.db $59, %0100, $59, %0100
.db $59, %0101, $f9, %0101
.db $59, %0110, $53, %0100
.db $59, %0111, $f3, %0101
.db $59, %1000, $59, %0000
.db $59, %1001, $b9, %0001
.db $59, %1010, $5f, %0000
.db $59, %1011, $bf, %0001
.db $59, %1100, $59, %0100
.db $59, %1101, $f9, %0101
.db $59, %1110, $53, %0100
.db $59, %1111, $f3, %0101
.db $5a, %0000, $60, %0000
.db $5a, %0001, $c0, %0001
.db $5a, %0010, $60, %0000
.db $5a, %0011, $c0, %0001
.db $5a, %0100, $5a, %0100
.db $5a, %0101, $fa, %0101
.db $5a, %0110, $54, %0100
.db $5a, %0111, $f4, %0101
.db $5a, %1000, $60, %0000
.db $5a, %1001, $c0, %0001
.db $5a, %1010, $60, %0000
.db $5a, %1011, $c0, %0001
.db $5a, %1100, $5a, %0100
.db $5a, %1101, $fa, %0101
.db $5a, %1110, $54, %0100
.db $5a, %1111, $f4, %0101
.db $5b, %0000, $61, %0000
.db $5b, %0001, $c1, %0001
.db $5b, %0010, $61, %0000
.db $5b, %0011, $c1, %0001
.db $5b, %0100, $5b, %0100
.db $5b, %0101, $fb, %0101
.db $5b, %0110, $55, %0100
.db $5b, %0111, $f5, %0101
.db $5b, %1000, $61, %0000
.db $5b, %1001, $c1, %0001
.db $5b, %1010, $61, %0000
.db $5b, %1011, $c1, %0001
.db $5b, %1100, $5b, %0100
.db $5b, %1101, $fb, %0101
.db $5b, %1110, $55, %0100
.db $5b, %1111, $f5, %0101
.db $5c, %0000, $62, %0000
.db $5c, %0001, $c2, %0001
.db $5c, %0010, $62, %0000
.db $5c, %0011, $c2, %0001
.db $5c, %0100, $5c, %0100
.db $5c, %0101, $fc, %0101
.db $5c, %0110, $56, %0100
.db $5c, %0111, $f6, %0101
.db $5c, %1000, $62, %0000
.db $5c, %1001, $c2, %0001
.db $5c, %1010, $62, %0000
.db $5c, %1011, $c2, %0001
.db $5c, %1100, $5c, %0100
.db $5c, %1101, $fc, %0101
.db $5c, %1110, $56, %0100
.db $5c, %1111, $f6, %0101
.db $5d, %0000, $63, %0000
.db $5d, %0001, $c3, %0001
.db $5d, %0010, $63, %0000
.db $5d, %0011, $c3, %0001
.db $5d, %0100, $5d, %0100
.db $5d, %0101, $fd, %0101
.db $5d, %0110, $57, %0100
.db $5d, %0111, $f7, %0101
.db $5d, %1000, $63, %0000
.db $5d, %1001, $c3, %0001
.db $5d, %1010, $63, %0000
.db $5d, %1011, $c3, %0001
.db $5d, %1100, $5d, %0100
.db $5d, %1101, $fd, %0101
.db $5d, %1110, $57, %0100
.db $5d, %1111, $f7, %0101
.db $5e, %0000, $64, %0000
.db $5e, %0001, $c4, %0001
.db $5e, %0010, $64, %0000
.db $5e, %0011, $c4, %0001
.db $5e, %0100, $5e, %0100
.db $5e, %0101, $fe, %0101
.db $5e, %0110, $58, %0100
.db $5e, %0111, $f8, %0101
.db $5e, %1000, $64, %0000
.db $5e, %1001, $c4, %0001
.db $5e, %1010, $64, %0000
.db $5e, %1011, $c4, %0001
.db $5e, %1100, $5e, %0100
.db $5e, %1101, $fe, %0101
.db $5e, %1110, $58, %0100
.db $5e, %1111, $f8, %0101
.db $5f, %0000, $65, %0000
.db $5f, %0001, $c5, %0001
.db $5f, %0010, $65, %0000
.db $5f, %0011, $c5, %0001
.db $5f, %0100, $5f, %0100
.db $5f, %0101, $ff, %0101
.db $5f, %0110, $59, %0100
.db $5f, %0111, $f9, %0101
.db $5f, %1000, $65, %0000
.db $5f, %1001, $c5, %0001
.db $5f, %1010, $65, %0000
.db $5f, %1011, $c5, %0001
.db $5f, %1100, $5f, %0100
.db $5f, %1101, $ff, %0101
.db $5f, %1110, $59, %0100
.db $5f, %1111, $f9, %0101
.db $60, %0000, $60, %0000
.db $60, %0001, $c0, %0001
.db $60, %0010, $66, %0000
.db $60, %0011, $c6, %0001
.db $60, %0100, $60, %0100
.db $60, %0101, $00, %1101
.db $60, %0110, $5a, %0100
.db $60, %0111, $fa, %0101
.db $60, %1000, $60, %0000
.db $60, %1001, $c0, %0001
.db $60, %1010, $66, %0000
.db $60, %1011, $c6, %0001
.db $60, %1100, $60, %0100
.db $60, %1101, $00, %1101
.db $60, %1110, $5a, %0100
.db $60, %1111, $fa, %0101
.db $61, %0000, $61, %0000
.db $61, %0001, $c1, %0001
.db $61, %0010, $67, %0000
.db $61, %0011, $c7, %0001
.db $61, %0100, $61, %0100
.db $61, %0101, $01, %0101
.db $61, %0110, $5b, %0100
.db $61, %0111, $fb, %0101
.db $61, %1000, $61, %0000
.db $61, %1001, $c1, %0001
.db $61, %1010, $67, %0000
.db $61, %1011, $c7, %0001
.db $61, %1100, $61, %0100
.db $61, %1101, $01, %0101
.db $61, %1110, $5b, %0100
.db $61, %1111, $fb, %0101
.db $62, %0000, $62, %0000
.db $62, %0001, $c2, %0001
.db $62, %0010, $68, %0000
.db $62, %0011, $c8, %0001
.db $62, %0100, $62, %0100
.db $62, %0101, $02, %0101
.db $62, %0110, $5c, %0100
.db $62, %0111, $fc, %0101
.db $62, %1000, $62, %0000
.db $62, %1001, $c2, %0001
.db $62, %1010, $68, %0000
.db $62, %1011, $c8, %0001
.db $62, %1100, $62, %0100
.db $62, %1101, $02, %0101
.db $62, %1110, $5c, %0100
.db $62, %1111, $fc, %0101
.db $63, %0000, $63, %0000
.db $63, %0001, $c3, %0001
.db $63, %0010, $69, %0000
.db $63, %0011, $c9, %0001
.db $63, %0100, $63, %0100
.db $63, %0101, $03, %0101
.db $63, %0110, $5d, %0100
.db $63, %0111, $fd, %0101
.db $63, %1000, $63, %0000
.db $63, %1001, $c3, %0001
.db $63, %1010, $69, %0000
.db $63, %1011, $c9, %0001
.db $63, %1100, $63, %0100
.db $63, %1101, $03, %0101
.db $63, %1110, $5d, %0100
.db $63, %1111, $fd, %0101
.db $64, %0000, $64, %0000
.db $64, %0001, $c4, %0001
.db $64, %0010, $6a, %0000
.db $64, %0011, $ca, %0001
.db $64, %0100, $64, %0100
.db $64, %0101, $04, %0101
.db $64, %0110, $5e, %0100
.db $64, %0111, $fe, %0101
.db $64, %1000, $64, %0000
.db $64, %1001, $c4, %0001
.db $64, %1010, $6a, %0000
.db $64, %1011, $ca, %0001
.db $64, %1100, $64, %0100
.db $64, %1101, $04, %0101
.db $64, %1110, $5e, %0100
.db $64, %1111, $fe, %0101
.db $65, %0000, $65, %0000
.db $65, %0001, $c5, %0001
.db $65, %0010, $6b, %0000
.db $65, %0011, $cb, %0001
.db $65, %0100, $65, %0100
.db $65, %0101, $05, %0101
.db $65, %0110, $5f, %0100
.db $65, %0111, $ff, %0101
.db $65, %1000, $65, %0000
.db $65, %1001, $c5, %0001
.db $65, %1010, $6b, %0000
.db $65, %1011, $cb, %0001
.db $65, %1100, $65, %0100
.db $65, %1101, $05, %0101
.db $65, %1110, $5f, %0100
.db $65, %1111, $ff, %0101
.db $66, %0000, $66, %0000
.db $66, %0001, $c6, %0001
.db $66, %0010, $6c, %0000
.db $66, %0011, $cc, %0001
.db $66, %0100, $66, %0100
.db $66, %0101, $06, %0101
.db $66, %0110, $60, %0100
.db $66, %0111, $00, %1101
.db $66, %1000, $66, %0000
.db $66, %1001, $c6, %0001
.db $66, %1010, $6c, %0000
.db $66, %1011, $cc, %0001
.db $66, %1100, $66, %0100
.db $66, %1101, $06, %0101
.db $66, %1110, $60, %0100
.db $66, %1111, $00, %1101
.db $67, %0000, $67, %0000
.db $67, %0001, $c7, %0001
.db $67, %0010, $6d, %0000
.db $67, %0011, $cd, %0001
.db $67, %0100, $67, %0100
.db $67, %0101, $07, %0101
.db $67, %0110, $61, %0100
.db $67, %0111, $01, %0101
.db $67, %1000, $67, %0000
.db $67, %1001, $c7, %0001
.db $67, %1010, $6d, %0000
.db $67, %1011, $cd, %0001
.db $67, %1100, $67, %0100
.db $67, %1101, $07, %0101
.db $67, %1110, $61, %0100
.db $67, %1111, $01, %0101
.db $68, %0000, $68, %0000
.db $68, %0001, $c8, %0001
.db $68, %0010, $6e, %0000
.db $68, %0011, $ce, %0001
.db $68, %0100, $68, %0100
.db $68, %0101, $08, %0101
.db $68, %0110, $62, %0100
.db $68, %0111, $02, %0101
.db $68, %1000, $68, %0000
.db $68, %1001, $c8, %0001
.db $68, %1010, $6e, %0000
.db $68, %1011, $ce, %0001
.db $68, %1100, $68, %0100
.db $68, %1101, $08, %0101
.db $68, %1110, $62, %0100
.db $68, %1111, $02, %0101
.db $69, %0000, $69, %0000
.db $69, %0001, $c9, %0001
.db $69, %0010, $6f, %0000
.db $69, %0011, $cf, %0001
.db $69, %0100, $69, %0100
.db $69, %0101, $09, %0101
.db $69, %0110, $63, %0100
.db $69, %0111, $03, %0101
.db $69, %1000, $69, %0000
.db $69, %1001, $c9, %0001
.db $69, %1010, $6f, %0000
.db $69, %1011, $cf, %0001
.db $69, %1100, $69, %0100
.db $69, %1101, $09, %0101
.db $69, %1110, $63, %0100
.db $69, %1111, $03, %0101
.db $6a, %0000, $70, %0000
.db $6a, %0001, $d0, %0001
.db $6a, %0010, $70, %0000
.db $6a, %0011, $d0, %0001
.db $6a, %0100, $6a, %0100
.db $6a, %0101, $0a, %0101
.db $6a, %0110, $64, %0100
.db $6a, %0111, $04, %0101
.db $6a, %1000, $70, %0000
.db $6a, %1001, $d0, %0001
.db $6a, %1010, $70, %0000
.db $6a, %1011, $d0, %0001
.db $6a, %1100, $6a, %0100
.db $6a, %1101, $0a, %0101
.db $6a, %1110, $64, %0100
.db $6a, %1111, $04, %0101
.db $6b, %0000, $71, %0000
.db $6b, %0001, $d1, %0001
.db $6b, %0010, $71, %0000
.db $6b, %0011, $d1, %0001
.db $6b, %0100, $6b, %0100
.db $6b, %0101, $0b, %0101
.db $6b, %0110, $65, %0100
.db $6b, %0111, $05, %0101
.db $6b, %1000, $71, %0000
.db $6b, %1001, $d1, %0001
.db $6b, %1010, $71, %0000
.db $6b, %1011, $d1, %0001
.db $6b, %1100, $6b, %0100
.db $6b, %1101, $0b, %0101
.db $6b, %1110, $65, %0100
.db $6b, %1111, $05, %0101
.db $6c, %0000, $72, %0000
.db $6c, %0001, $d2, %0001
.db $6c, %0010, $72, %0000
.db $6c, %0011, $d2, %0001
.db $6c, %0100, $6c, %0100
.db $6c, %0101, $0c, %0101
.db $6c, %0110, $66, %0100
.db $6c, %0111, $06, %0101
.db $6c, %1000, $72, %0000
.db $6c, %1001, $d2, %0001
.db $6c, %1010, $72, %0000
.db $6c, %1011, $d2, %0001
.db $6c, %1100, $6c, %0100
.db $6c, %1101, $0c, %0101
.db $6c, %1110, $66, %0100
.db $6c, %1111, $06, %0101
.db $6d, %0000, $73, %0000
.db $6d, %0001, $d3, %0001
.db $6d, %0010, $73, %0000
.db $6d, %0011, $d3, %0001
.db $6d, %0100, $6d, %0100
.db $6d, %0101, $0d, %0101
.db $6d, %0110, $67, %0100
.db $6d, %0111, $07, %0101
.db $6d, %1000, $73, %0000
.db $6d, %1001, $d3, %0001
.db $6d, %1010, $73, %0000
.db $6d, %1011, $d3, %0001
.db $6d, %1100, $6d, %0100
.db $6d, %1101, $0d, %0101
.db $6d, %1110, $67, %0100
.db $6d, %1111, $07, %0101
.db $6e, %0000, $74, %0000
.db $6e, %0001, $d4, %0001
.db $6e, %0010, $74, %0000
.db $6e, %0011, $d4, %0001
.db $6e, %0100, $6e, %0100
.db $6e, %0101, $0e, %0101
.db $6e, %0110, $68, %0100
.db $6e, %0111, $08, %0101
.db $6e, %1000, $74, %0000
.db $6e, %1001, $d4, %0001
.db $6e, %1010, $74, %0000
.db $6e, %1011, $d4, %0001
.db $6e, %1100, $6e, %0100
.db $6e, %1101, $0e, %0101
.db $6e, %1110, $68, %0100
.db $6e, %1111, $08, %0101
.db $6f, %0000, $75, %0000
.db $6f, %0001, $d5, %0001
.db $6f, %0010, $75, %0000
.db $6f, %0011, $d5, %0001
.db $6f, %0100, $6f, %0100
.db $6f, %0101, $0f, %0101
.db $6f, %0110, $69, %0100
.db $6f, %0111, $09, %0101
.db $6f, %1000, $75, %0000
.db $6f, %1001, $d5, %0001
.db $6f, %1010, $75, %0000
.db $6f, %1011, $d5, %0001
.db $6f, %1100, $6f, %0100
.db $6f, %1101, $0f, %0101
.db $6f, %1110, $69, %0100
.db $6f, %1111, $09, %0101
.db $70, %0000, $70, %0000
.db $70, %0001, $d0, %0001
.db $70, %0010, $76, %0000
.db $70, %0011, $d6, %0001
.db $70, %0100, $70, %0100
.db $70, %0101, $10, %0101
.db $70, %0110, $6a, %0100
.db $70, %0111, $0a, %0101
.db $70, %1000, $70, %0000
.db $70, %1001, $d0, %0001
.db $70, %1010, $76, %0000
.db $70, %1011, $d6, %0001
.db $70, %1100, $70, %0100
.db $70, %1101, $10, %0101
.db $70, %1110, $6a, %0100
.db $70, %1111, $0a, %0101
.db $71, %0000, $71, %0000
.db $71, %0001, $d1, %0001
.db $71, %0010, $77, %0000
.db $71, %0011, $d7, %0001
.db $71, %0100, $71, %0100
.db $71, %0101, $11, %0101
.db $71, %0110, $6b, %0100
.db $71, %0111, $0b, %0101
.db $71, %1000, $71, %0000
.db $71, %1001, $d1, %0001
.db $71, %1010, $77, %0000
.db $71, %1011, $d7, %0001
.db $71, %1100, $71, %0100
.db $71, %1101, $11, %0101
.db $71, %1110, $6b, %0100
.db $71, %1111, $0b, %0101
.db $72, %0000, $72, %0000
.db $72, %0001, $d2, %0001
.db $72, %0010, $78, %0000
.db $72, %0011, $d8, %0001
.db $72, %0100, $72, %0100
.db $72, %0101, $12, %0101
.db $72, %0110, $6c, %0100
.db $72, %0111, $0c, %0101
.db $72, %1000, $72, %0000
.db $72, %1001, $d2, %0001
.db $72, %1010, $78, %0000
.db $72, %1011, $d8, %0001
.db $72, %1100, $72, %0100
.db $72, %1101, $12, %0101
.db $72, %1110, $6c, %0100
.db $72, %1111, $0c, %0101
.db $73, %0000, $73, %0000
.db $73, %0001, $d3, %0001
.db $73, %0010, $79, %0000
.db $73, %0011, $d9, %0001
.db $73, %0100, $73, %0100
.db $73, %0101, $13, %0101
.db $73, %0110, $6d, %0100
.db $73, %0111, $0d, %0101
.db $73, %1000, $73, %0000
.db $73, %1001, $d3, %0001
.db $73, %1010, $79, %0000
.db $73, %1011, $d9, %0001
.db $73, %1100, $73, %0100
.db $73, %1101, $13, %0101
.db $73, %1110, $6d, %0100
.db $73, %1111, $0d, %0101
.db $74, %0000, $74, %0000
.db $74, %0001, $d4, %0001
.db $74, %0010, $7a, %0000
.db $74, %0011, $da, %0001
.db $74, %0100, $74, %0100
.db $74, %0101, $14, %0101
.db $74, %0110, $6e, %0100
.db $74, %0111, $0e, %0101
.db $74, %1000, $74, %0000
.db $74, %1001, $d4, %0001
.db $74, %1010, $7a, %0000
.db $74, %1011, $da, %0001
.db $74, %1100, $74, %0100
.db $74, %1101, $14, %0101
.db $74, %1110, $6e, %0100
.db $74, %1111, $0e, %0101
.db $75, %0000, $75, %0000
.db $75, %0001, $d5, %0001
.db $75, %0010, $7b, %0000
.db $75, %0011, $db, %0001
.db $75, %0100, $75, %0100
.db $75, %0101, $15, %0101
.db $75, %0110, $6f, %0100
.db $75, %0111, $0f, %0101
.db $75, %1000, $75, %0000
.db $75, %1001, $d5, %0001
.db $75, %1010, $7b, %0000
.db $75, %1011, $db, %0001
.db $75, %1100, $75, %0100
.db $75, %1101, $15, %0101
.db $75, %1110, $6f, %0100
.db $75, %1111, $0f, %0101
.db $76, %0000, $76, %0000
.db $76, %0001, $d6, %0001
.db $76, %0010, $7c, %0000
.db $76, %0011, $dc, %0001
.db $76, %0100, $76, %0100
.db $76, %0101, $16, %0101
.db $76, %0110, $70, %0100
.db $76, %0111, $10, %0101
.db $76, %1000, $76, %0000
.db $76, %1001, $d6, %0001
.db $76, %1010, $7c, %0000
.db $76, %1011, $dc, %0001
.db $76, %1100, $76, %0100
.db $76, %1101, $16, %0101
.db $76, %1110, $70, %0100
.db $76, %1111, $10, %0101
.db $77, %0000, $77, %0000
.db $77, %0001, $d7, %0001
.db $77, %0010, $7d, %0000
.db $77, %0011, $dd, %0001
.db $77, %0100, $77, %0100
.db $77, %0101, $17, %0101
.db $77, %0110, $71, %0100
.db $77, %0111, $11, %0101
.db $77, %1000, $77, %0000
.db $77, %1001, $d7, %0001
.db $77, %1010, $7d, %0000
.db $77, %1011, $dd, %0001
.db $77, %1100, $77, %0100
.db $77, %1101, $17, %0101
.db $77, %1110, $71, %0100
.db $77, %1111, $11, %0101
.db $78, %0000, $78, %0000
.db $78, %0001, $d8, %0001
.db $78, %0010, $7e, %0000
.db $78, %0011, $de, %0001
.db $78, %0100, $78, %0100
.db $78, %0101, $18, %0101
.db $78, %0110, $72, %0100
.db $78, %0111, $12, %0101
.db $78, %1000, $78, %0000
.db $78, %1001, $d8, %0001
.db $78, %1010, $7e, %0000
.db $78, %1011, $de, %0001
.db $78, %1100, $78, %0100
.db $78, %1101, $18, %0101
.db $78, %1110, $72, %0100
.db $78, %1111, $12, %0101
.db $79, %0000, $79, %0000
.db $79, %0001, $d9, %0001
.db $79, %0010, $7f, %0000
.db $79, %0011, $df, %0001
.db $79, %0100, $79, %0100
.db $79, %0101, $19, %0101
.db $79, %0110, $73, %0100
.db $79, %0111, $13, %0101
.db $79, %1000, $79, %0000
.db $79, %1001, $d9, %0001
.db $79, %1010, $7f, %0000
.db $79, %1011, $df, %0001
.db $79, %1100, $79, %0100
.db $79, %1101, $19, %0101
.db $79, %1110, $73, %0100
.db $79, %1111, $13, %0101
.db $7a, %0000, $80, %0000
.db $7a, %0001, $e0, %0001
.db $7a, %0010, $80, %0000
.db $7a, %0011, $e0, %0001
.db $7a, %0100, $7a, %0100
.db $7a, %0101, $1a, %0101
.db $7a, %0110, $74, %0100
.db $7a, %0111, $14, %0101
.db $7a, %1000, $80, %0000
.db $7a, %1001, $e0, %0001
.db $7a, %1010, $80, %0000
.db $7a, %1011, $e0, %0001
.db $7a, %1100, $7a, %0100
.db $7a, %1101, $1a, %0101
.db $7a, %1110, $74, %0100
.db $7a, %1111, $14, %0101
.db $7b, %0000, $81, %0000
.db $7b, %0001, $e1, %0001
.db $7b, %0010, $81, %0000
.db $7b, %0011, $e1, %0001
.db $7b, %0100, $7b, %0100
.db $7b, %0101, $1b, %0101
.db $7b, %0110, $75, %0100
.db $7b, %0111, $15, %0101
.db $7b, %1000, $81, %0000
.db $7b, %1001, $e1, %0001
.db $7b, %1010, $81, %0000
.db $7b, %1011, $e1, %0001
.db $7b, %1100, $7b, %0100
.db $7b, %1101, $1b, %0101
.db $7b, %1110, $75, %0100
.db $7b, %1111, $15, %0101
.db $7c, %0000, $82, %0000
.db $7c, %0001, $e2, %0001
.db $7c, %0010, $82, %0000
.db $7c, %0011, $e2, %0001
.db $7c, %0100, $7c, %0100
.db $7c, %0101, $1c, %0101
.db $7c, %0110, $76, %0100
.db $7c, %0111, $16, %0101
.db $7c, %1000, $82, %0000
.db $7c, %1001, $e2, %0001
.db $7c, %1010, $82, %0000
.db $7c, %1011, $e2, %0001
.db $7c, %1100, $7c, %0100
.db $7c, %1101, $1c, %0101
.db $7c, %1110, $76, %0100
.db $7c, %1111, $16, %0101
.db $7d, %0000, $83, %0000
.db $7d, %0001, $e3, %0001
.db $7d, %0010, $83, %0000
.db $7d, %0011, $e3, %0001
.db $7d, %0100, $7d, %0100
.db $7d, %0101, $1d, %0101
.db $7d, %0110, $77, %0100
.db $7d, %0111, $17, %0101
.db $7d, %1000, $83, %0000
.db $7d, %1001, $e3, %0001
.db $7d, %1010, $83, %0000
.db $7d, %1011, $e3, %0001
.db $7d, %1100, $7d, %0100
.db $7d, %1101, $1d, %0101
.db $7d, %1110, $77, %0100
.db $7d, %1111, $17, %0101
.db $7e, %0000, $84, %0000
.db $7e, %0001, $e4, %0001
.db $7e, %0010, $84, %0000
.db $7e, %0011, $e4, %0001
.db $7e, %0100, $7e, %0100
.db $7e, %0101, $1e, %0101
.db $7e, %0110, $78, %0100
.db $7e, %0111, $18, %0101
.db $7e, %1000, $84, %0000
.db $7e, %1001, $e4, %0001
.db $7e, %1010, $84, %0000
.db $7e, %1011, $e4, %0001
.db $7e, %1100, $7e, %0100
.db $7e, %1101, $1e, %0101
.db $7e, %1110, $78, %0100
.db $7e, %1111, $18, %0101
.db $7f, %0000, $85, %0000
.db $7f, %0001, $e5, %0001
.db $7f, %0010, $85, %0000
.db $7f, %0011, $e5, %0001
.db $7f, %0100, $7f, %0100
.db $7f, %0101, $1f, %0101
.db $7f, %0110, $79, %0100
.db $7f, %0111, $19, %0101
.db $7f, %1000, $85, %0000
.db $7f, %1001, $e5, %0001
.db $7f, %1010, $85, %0000
.db $7f, %1011, $e5, %0001
.db $7f, %1100, $7f, %0100
.db $7f, %1101, $1f, %0101
.db $7f, %1110, $79, %0100
.db $7f, %1111, $19, %0101
.ends

.bank 1 slot 1
.section "testcases2"
testcases2:
.db $80, %0000, $80, %0000
.db $80, %0001, $e0, %0001
.db $80, %0010, $86, %0000
.db $80, %0011, $e6, %0001
.db $80, %0100, $80, %0100
.db $80, %0101, $20, %0101
.db $80, %0110, $7a, %0100
.db $80, %0111, $1a, %0101
.db $80, %1000, $80, %0000
.db $80, %1001, $e0, %0001
.db $80, %1010, $86, %0000
.db $80, %1011, $e6, %0001
.db $80, %1100, $80, %0100
.db $80, %1101, $20, %0101
.db $80, %1110, $7a, %0100
.db $80, %1111, $1a, %0101
.db $81, %0000, $81, %0000
.db $81, %0001, $e1, %0001
.db $81, %0010, $87, %0000
.db $81, %0011, $e7, %0001
.db $81, %0100, $81, %0100
.db $81, %0101, $21, %0101
.db $81, %0110, $7b, %0100
.db $81, %0111, $1b, %0101
.db $81, %1000, $81, %0000
.db $81, %1001, $e1, %0001
.db $81, %1010, $87, %0000
.db $81, %1011, $e7, %0001
.db $81, %1100, $81, %0100
.db $81, %1101, $21, %0101
.db $81, %1110, $7b, %0100
.db $81, %1111, $1b, %0101
.db $82, %0000, $82, %0000
.db $82, %0001, $e2, %0001
.db $82, %0010, $88, %0000
.db $82, %0011, $e8, %0001
.db $82, %0100, $82, %0100
.db $82, %0101, $22, %0101
.db $82, %0110, $7c, %0100
.db $82, %0111, $1c, %0101
.db $82, %1000, $82, %0000
.db $82, %1001, $e2, %0001
.db $82, %1010, $88, %0000
.db $82, %1011, $e8, %0001
.db $82, %1100, $82, %0100
.db $82, %1101, $22, %0101
.db $82, %1110, $7c, %0100
.db $82, %1111, $1c, %0101
.db $83, %0000, $83, %0000
.db $83, %0001, $e3, %0001
.db $83, %0010, $89, %0000
.db $83, %0011, $e9, %0001
.db $83, %0100, $83, %0100
.db $83, %0101, $23, %0101
.db $83, %0110, $7d, %0100
.db $83, %0111, $1d, %0101
.db $83, %1000, $83, %0000
.db $83, %1001, $e3, %0001
.db $83, %1010, $89, %0000
.db $83, %1011, $e9, %0001
.db $83, %1100, $83, %0100
.db $83, %1101, $23, %0101
.db $83, %1110, $7d, %0100
.db $83, %1111, $1d, %0101
.db $84, %0000, $84, %0000
.db $84, %0001, $e4, %0001
.db $84, %0010, $8a, %0000
.db $84, %0011, $ea, %0001
.db $84, %0100, $84, %0100
.db $84, %0101, $24, %0101
.db $84, %0110, $7e, %0100
.db $84, %0111, $1e, %0101
.db $84, %1000, $84, %0000
.db $84, %1001, $e4, %0001
.db $84, %1010, $8a, %0000
.db $84, %1011, $ea, %0001
.db $84, %1100, $84, %0100
.db $84, %1101, $24, %0101
.db $84, %1110, $7e, %0100
.db $84, %1111, $1e, %0101
.db $85, %0000, $85, %0000
.db $85, %0001, $e5, %0001
.db $85, %0010, $8b, %0000
.db $85, %0011, $eb, %0001
.db $85, %0100, $85, %0100
.db $85, %0101, $25, %0101
.db $85, %0110, $7f, %0100
.db $85, %0111, $1f, %0101
.db $85, %1000, $85, %0000
.db $85, %1001, $e5, %0001
.db $85, %1010, $8b, %0000
.db $85, %1011, $eb, %0001
.db $85, %1100, $85, %0100
.db $85, %1101, $25, %0101
.db $85, %1110, $7f, %0100
.db $85, %1111, $1f, %0101
.db $86, %0000, $86, %0000
.db $86, %0001, $e6, %0001
.db $86, %0010, $8c, %0000
.db $86, %0011, $ec, %0001
.db $86, %0100, $86, %0100
.db $86, %0101, $26, %0101
.db $86, %0110, $80, %0100
.db $86, %0111, $20, %0101
.db $86, %1000, $86, %0000
.db $86, %1001, $e6, %0001
.db $86, %1010, $8c, %0000
.db $86, %1011, $ec, %0001
.db $86, %1100, $86, %0100
.db $86, %1101, $26, %0101
.db $86, %1110, $80, %0100
.db $86, %1111, $20, %0101
.db $87, %0000, $87, %0000
.db $87, %0001, $e7, %0001
.db $87, %0010, $8d, %0000
.db $87, %0011, $ed, %0001
.db $87, %0100, $87, %0100
.db $87, %0101, $27, %0101
.db $87, %0110, $81, %0100
.db $87, %0111, $21, %0101
.db $87, %1000, $87, %0000
.db $87, %1001, $e7, %0001
.db $87, %1010, $8d, %0000
.db $87, %1011, $ed, %0001
.db $87, %1100, $87, %0100
.db $87, %1101, $27, %0101
.db $87, %1110, $81, %0100
.db $87, %1111, $21, %0101
.db $88, %0000, $88, %0000
.db $88, %0001, $e8, %0001
.db $88, %0010, $8e, %0000
.db $88, %0011, $ee, %0001
.db $88, %0100, $88, %0100
.db $88, %0101, $28, %0101
.db $88, %0110, $82, %0100
.db $88, %0111, $22, %0101
.db $88, %1000, $88, %0000
.db $88, %1001, $e8, %0001
.db $88, %1010, $8e, %0000
.db $88, %1011, $ee, %0001
.db $88, %1100, $88, %0100
.db $88, %1101, $28, %0101
.db $88, %1110, $82, %0100
.db $88, %1111, $22, %0101
.db $89, %0000, $89, %0000
.db $89, %0001, $e9, %0001
.db $89, %0010, $8f, %0000
.db $89, %0011, $ef, %0001
.db $89, %0100, $89, %0100
.db $89, %0101, $29, %0101
.db $89, %0110, $83, %0100
.db $89, %0111, $23, %0101
.db $89, %1000, $89, %0000
.db $89, %1001, $e9, %0001
.db $89, %1010, $8f, %0000
.db $89, %1011, $ef, %0001
.db $89, %1100, $89, %0100
.db $89, %1101, $29, %0101
.db $89, %1110, $83, %0100
.db $89, %1111, $23, %0101
.db $8a, %0000, $90, %0000
.db $8a, %0001, $f0, %0001
.db $8a, %0010, $90, %0000
.db $8a, %0011, $f0, %0001
.db $8a, %0100, $8a, %0100
.db $8a, %0101, $2a, %0101
.db $8a, %0110, $84, %0100
.db $8a, %0111, $24, %0101
.db $8a, %1000, $90, %0000
.db $8a, %1001, $f0, %0001
.db $8a, %1010, $90, %0000
.db $8a, %1011, $f0, %0001
.db $8a, %1100, $8a, %0100
.db $8a, %1101, $2a, %0101
.db $8a, %1110, $84, %0100
.db $8a, %1111, $24, %0101
.db $8b, %0000, $91, %0000
.db $8b, %0001, $f1, %0001
.db $8b, %0010, $91, %0000
.db $8b, %0011, $f1, %0001
.db $8b, %0100, $8b, %0100
.db $8b, %0101, $2b, %0101
.db $8b, %0110, $85, %0100
.db $8b, %0111, $25, %0101
.db $8b, %1000, $91, %0000
.db $8b, %1001, $f1, %0001
.db $8b, %1010, $91, %0000
.db $8b, %1011, $f1, %0001
.db $8b, %1100, $8b, %0100
.db $8b, %1101, $2b, %0101
.db $8b, %1110, $85, %0100
.db $8b, %1111, $25, %0101
.db $8c, %0000, $92, %0000
.db $8c, %0001, $f2, %0001
.db $8c, %0010, $92, %0000
.db $8c, %0011, $f2, %0001
.db $8c, %0100, $8c, %0100
.db $8c, %0101, $2c, %0101
.db $8c, %0110, $86, %0100
.db $8c, %0111, $26, %0101
.db $8c, %1000, $92, %0000
.db $8c, %1001, $f2, %0001
.db $8c, %1010, $92, %0000
.db $8c, %1011, $f2, %0001
.db $8c, %1100, $8c, %0100
.db $8c, %1101, $2c, %0101
.db $8c, %1110, $86, %0100
.db $8c, %1111, $26, %0101
.db $8d, %0000, $93, %0000
.db $8d, %0001, $f3, %0001
.db $8d, %0010, $93, %0000
.db $8d, %0011, $f3, %0001
.db $8d, %0100, $8d, %0100
.db $8d, %0101, $2d, %0101
.db $8d, %0110, $87, %0100
.db $8d, %0111, $27, %0101
.db $8d, %1000, $93, %0000
.db $8d, %1001, $f3, %0001
.db $8d, %1010, $93, %0000
.db $8d, %1011, $f3, %0001
.db $8d, %1100, $8d, %0100
.db $8d, %1101, $2d, %0101
.db $8d, %1110, $87, %0100
.db $8d, %1111, $27, %0101
.db $8e, %0000, $94, %0000
.db $8e, %0001, $f4, %0001
.db $8e, %0010, $94, %0000
.db $8e, %0011, $f4, %0001
.db $8e, %0100, $8e, %0100
.db $8e, %0101, $2e, %0101
.db $8e, %0110, $88, %0100
.db $8e, %0111, $28, %0101
.db $8e, %1000, $94, %0000
.db $8e, %1001, $f4, %0001
.db $8e, %1010, $94, %0000
.db $8e, %1011, $f4, %0001
.db $8e, %1100, $8e, %0100
.db $8e, %1101, $2e, %0101
.db $8e, %1110, $88, %0100
.db $8e, %1111, $28, %0101
.db $8f, %0000, $95, %0000
.db $8f, %0001, $f5, %0001
.db $8f, %0010, $95, %0000
.db $8f, %0011, $f5, %0001
.db $8f, %0100, $8f, %0100
.db $8f, %0101, $2f, %0101
.db $8f, %0110, $89, %0100
.db $8f, %0111, $29, %0101
.db $8f, %1000, $95, %0000
.db $8f, %1001, $f5, %0001
.db $8f, %1010, $95, %0000
.db $8f, %1011, $f5, %0001
.db $8f, %1100, $8f, %0100
.db $8f, %1101, $2f, %0101
.db $8f, %1110, $89, %0100
.db $8f, %1111, $29, %0101
.db $90, %0000, $90, %0000
.db $90, %0001, $f0, %0001
.db $90, %0010, $96, %0000
.db $90, %0011, $f6, %0001
.db $90, %0100, $90, %0100
.db $90, %0101, $30, %0101
.db $90, %0110, $8a, %0100
.db $90, %0111, $2a, %0101
.db $90, %1000, $90, %0000
.db $90, %1001, $f0, %0001
.db $90, %1010, $96, %0000
.db $90, %1011, $f6, %0001
.db $90, %1100, $90, %0100
.db $90, %1101, $30, %0101
.db $90, %1110, $8a, %0100
.db $90, %1111, $2a, %0101
.db $91, %0000, $91, %0000
.db $91, %0001, $f1, %0001
.db $91, %0010, $97, %0000
.db $91, %0011, $f7, %0001
.db $91, %0100, $91, %0100
.db $91, %0101, $31, %0101
.db $91, %0110, $8b, %0100
.db $91, %0111, $2b, %0101
.db $91, %1000, $91, %0000
.db $91, %1001, $f1, %0001
.db $91, %1010, $97, %0000
.db $91, %1011, $f7, %0001
.db $91, %1100, $91, %0100
.db $91, %1101, $31, %0101
.db $91, %1110, $8b, %0100
.db $91, %1111, $2b, %0101
.db $92, %0000, $92, %0000
.db $92, %0001, $f2, %0001
.db $92, %0010, $98, %0000
.db $92, %0011, $f8, %0001
.db $92, %0100, $92, %0100
.db $92, %0101, $32, %0101
.db $92, %0110, $8c, %0100
.db $92, %0111, $2c, %0101
.db $92, %1000, $92, %0000
.db $92, %1001, $f2, %0001
.db $92, %1010, $98, %0000
.db $92, %1011, $f8, %0001
.db $92, %1100, $92, %0100
.db $92, %1101, $32, %0101
.db $92, %1110, $8c, %0100
.db $92, %1111, $2c, %0101
.db $93, %0000, $93, %0000
.db $93, %0001, $f3, %0001
.db $93, %0010, $99, %0000
.db $93, %0011, $f9, %0001
.db $93, %0100, $93, %0100
.db $93, %0101, $33, %0101
.db $93, %0110, $8d, %0100
.db $93, %0111, $2d, %0101
.db $93, %1000, $93, %0000
.db $93, %1001, $f3, %0001
.db $93, %1010, $99, %0000
.db $93, %1011, $f9, %0001
.db $93, %1100, $93, %0100
.db $93, %1101, $33, %0101
.db $93, %1110, $8d, %0100
.db $93, %1111, $2d, %0101
.db $94, %0000, $94, %0000
.db $94, %0001, $f4, %0001
.db $94, %0010, $9a, %0000
.db $94, %0011, $fa, %0001
.db $94, %0100, $94, %0100
.db $94, %0101, $34, %0101
.db $94, %0110, $8e, %0100
.db $94, %0111, $2e, %0101
.db $94, %1000, $94, %0000
.db $94, %1001, $f4, %0001
.db $94, %1010, $9a, %0000
.db $94, %1011, $fa, %0001
.db $94, %1100, $94, %0100
.db $94, %1101, $34, %0101
.db $94, %1110, $8e, %0100
.db $94, %1111, $2e, %0101
.db $95, %0000, $95, %0000
.db $95, %0001, $f5, %0001
.db $95, %0010, $9b, %0000
.db $95, %0011, $fb, %0001
.db $95, %0100, $95, %0100
.db $95, %0101, $35, %0101
.db $95, %0110, $8f, %0100
.db $95, %0111, $2f, %0101
.db $95, %1000, $95, %0000
.db $95, %1001, $f5, %0001
.db $95, %1010, $9b, %0000
.db $95, %1011, $fb, %0001
.db $95, %1100, $95, %0100
.db $95, %1101, $35, %0101
.db $95, %1110, $8f, %0100
.db $95, %1111, $2f, %0101
.db $96, %0000, $96, %0000
.db $96, %0001, $f6, %0001
.db $96, %0010, $9c, %0000
.db $96, %0011, $fc, %0001
.db $96, %0100, $96, %0100
.db $96, %0101, $36, %0101
.db $96, %0110, $90, %0100
.db $96, %0111, $30, %0101
.db $96, %1000, $96, %0000
.db $96, %1001, $f6, %0001
.db $96, %1010, $9c, %0000
.db $96, %1011, $fc, %0001
.db $96, %1100, $96, %0100
.db $96, %1101, $36, %0101
.db $96, %1110, $90, %0100
.db $96, %1111, $30, %0101
.db $97, %0000, $97, %0000
.db $97, %0001, $f7, %0001
.db $97, %0010, $9d, %0000
.db $97, %0011, $fd, %0001
.db $97, %0100, $97, %0100
.db $97, %0101, $37, %0101
.db $97, %0110, $91, %0100
.db $97, %0111, $31, %0101
.db $97, %1000, $97, %0000
.db $97, %1001, $f7, %0001
.db $97, %1010, $9d, %0000
.db $97, %1011, $fd, %0001
.db $97, %1100, $97, %0100
.db $97, %1101, $37, %0101
.db $97, %1110, $91, %0100
.db $97, %1111, $31, %0101
.db $98, %0000, $98, %0000
.db $98, %0001, $f8, %0001
.db $98, %0010, $9e, %0000
.db $98, %0011, $fe, %0001
.db $98, %0100, $98, %0100
.db $98, %0101, $38, %0101
.db $98, %0110, $92, %0100
.db $98, %0111, $32, %0101
.db $98, %1000, $98, %0000
.db $98, %1001, $f8, %0001
.db $98, %1010, $9e, %0000
.db $98, %1011, $fe, %0001
.db $98, %1100, $98, %0100
.db $98, %1101, $38, %0101
.db $98, %1110, $92, %0100
.db $98, %1111, $32, %0101
.db $99, %0000, $99, %0000
.db $99, %0001, $f9, %0001
.db $99, %0010, $9f, %0000
.db $99, %0011, $ff, %0001
.db $99, %0100, $99, %0100
.db $99, %0101, $39, %0101
.db $99, %0110, $93, %0100
.db $99, %0111, $33, %0101
.db $99, %1000, $99, %0000
.db $99, %1001, $f9, %0001
.db $99, %1010, $9f, %0000
.db $99, %1011, $ff, %0001
.db $99, %1100, $99, %0100
.db $99, %1101, $39, %0101
.db $99, %1110, $93, %0100
.db $99, %1111, $33, %0101
.db $9a, %0000, $00, %1001
.db $9a, %0001, $00, %1001
.db $9a, %0010, $00, %1001
.db $9a, %0011, $00, %1001
.db $9a, %0100, $9a, %0100
.db $9a, %0101, $3a, %0101
.db $9a, %0110, $94, %0100
.db $9a, %0111, $34, %0101
.db $9a, %1000, $00, %1001
.db $9a, %1001, $00, %1001
.db $9a, %1010, $00, %1001
.db $9a, %1011, $00, %1001
.db $9a, %1100, $9a, %0100
.db $9a, %1101, $3a, %0101
.db $9a, %1110, $94, %0100
.db $9a, %1111, $34, %0101
.db $9b, %0000, $01, %0001
.db $9b, %0001, $01, %0001
.db $9b, %0010, $01, %0001
.db $9b, %0011, $01, %0001
.db $9b, %0100, $9b, %0100
.db $9b, %0101, $3b, %0101
.db $9b, %0110, $95, %0100
.db $9b, %0111, $35, %0101
.db $9b, %1000, $01, %0001
.db $9b, %1001, $01, %0001
.db $9b, %1010, $01, %0001
.db $9b, %1011, $01, %0001
.db $9b, %1100, $9b, %0100
.db $9b, %1101, $3b, %0101
.db $9b, %1110, $95, %0100
.db $9b, %1111, $35, %0101
.db $9c, %0000, $02, %0001
.db $9c, %0001, $02, %0001
.db $9c, %0010, $02, %0001
.db $9c, %0011, $02, %0001
.db $9c, %0100, $9c, %0100
.db $9c, %0101, $3c, %0101
.db $9c, %0110, $96, %0100
.db $9c, %0111, $36, %0101
.db $9c, %1000, $02, %0001
.db $9c, %1001, $02, %0001
.db $9c, %1010, $02, %0001
.db $9c, %1011, $02, %0001
.db $9c, %1100, $9c, %0100
.db $9c, %1101, $3c, %0101
.db $9c, %1110, $96, %0100
.db $9c, %1111, $36, %0101
.db $9d, %0000, $03, %0001
.db $9d, %0001, $03, %0001
.db $9d, %0010, $03, %0001
.db $9d, %0011, $03, %0001
.db $9d, %0100, $9d, %0100
.db $9d, %0101, $3d, %0101
.db $9d, %0110, $97, %0100
.db $9d, %0111, $37, %0101
.db $9d, %1000, $03, %0001
.db $9d, %1001, $03, %0001
.db $9d, %1010, $03, %0001
.db $9d, %1011, $03, %0001
.db $9d, %1100, $9d, %0100
.db $9d, %1101, $3d, %0101
.db $9d, %1110, $97, %0100
.db $9d, %1111, $37, %0101
.db $9e, %0000, $04, %0001
.db $9e, %0001, $04, %0001
.db $9e, %0010, $04, %0001
.db $9e, %0011, $04, %0001
.db $9e, %0100, $9e, %0100
.db $9e, %0101, $3e, %0101
.db $9e, %0110, $98, %0100
.db $9e, %0111, $38, %0101
.db $9e, %1000, $04, %0001
.db $9e, %1001, $04, %0001
.db $9e, %1010, $04, %0001
.db $9e, %1011, $04, %0001
.db $9e, %1100, $9e, %0100
.db $9e, %1101, $3e, %0101
.db $9e, %1110, $98, %0100
.db $9e, %1111, $38, %0101
.db $9f, %0000, $05, %0001
.db $9f, %0001, $05, %0001
.db $9f, %0010, $05, %0001
.db $9f, %0011, $05, %0001
.db $9f, %0100, $9f, %0100
.db $9f, %0101, $3f, %0101
.db $9f, %0110, $99, %0100
.db $9f, %0111, $39, %0101
.db $9f, %1000, $05, %0001
.db $9f, %1001, $05, %0001
.db $9f, %1010, $05, %0001
.db $9f, %1011, $05, %0001
.db $9f, %1100, $9f, %0100
.db $9f, %1101, $3f, %0101
.db $9f, %1110, $99, %0100
.db $9f, %1111, $39, %0101
.db $a0, %0000, $00, %1001
.db $a0, %0001, $00, %1001
.db $a0, %0010, $06, %0001
.db $a0, %0011, $06, %0001
.db $a0, %0100, $a0, %0100
.db $a0, %0101, $40, %0101
.db $a0, %0110, $9a, %0100
.db $a0, %0111, $3a, %0101
.db $a0, %1000, $00, %1001
.db $a0, %1001, $00, %1001
.db $a0, %1010, $06, %0001
.db $a0, %1011, $06, %0001
.db $a0, %1100, $a0, %0100
.db $a0, %1101, $40, %0101
.db $a0, %1110, $9a, %0100
.db $a0, %1111, $3a, %0101
.db $a1, %0000, $01, %0001
.db $a1, %0001, $01, %0001
.db $a1, %0010, $07, %0001
.db $a1, %0011, $07, %0001
.db $a1, %0100, $a1, %0100
.db $a1, %0101, $41, %0101
.db $a1, %0110, $9b, %0100
.db $a1, %0111, $3b, %0101
.db $a1, %1000, $01, %0001
.db $a1, %1001, $01, %0001
.db $a1, %1010, $07, %0001
.db $a1, %1011, $07, %0001
.db $a1, %1100, $a1, %0100
.db $a1, %1101, $41, %0101
.db $a1, %1110, $9b, %0100
.db $a1, %1111, $3b, %0101
.db $a2, %0000, $02, %0001
.db $a2, %0001, $02, %0001
.db $a2, %0010, $08, %0001
.db $a2, %0011, $08, %0001
.db $a2, %0100, $a2, %0100
.db $a2, %0101, $42, %0101
.db $a2, %0110, $9c, %0100
.db $a2, %0111, $3c, %0101
.db $a2, %1000, $02, %0001
.db $a2, %1001, $02, %0001
.db $a2, %1010, $08, %0001
.db $a2, %1011, $08, %0001
.db $a2, %1100, $a2, %0100
.db $a2, %1101, $42, %0101
.db $a2, %1110, $9c, %0100
.db $a2, %1111, $3c, %0101
.db $a3, %0000, $03, %0001
.db $a3, %0001, $03, %0001
.db $a3, %0010, $09, %0001
.db $a3, %0011, $09, %0001
.db $a3, %0100, $a3, %0100
.db $a3, %0101, $43, %0101
.db $a3, %0110, $9d, %0100
.db $a3, %0111, $3d, %0101
.db $a3, %1000, $03, %0001
.db $a3, %1001, $03, %0001
.db $a3, %1010, $09, %0001
.db $a3, %1011, $09, %0001
.db $a3, %1100, $a3, %0100
.db $a3, %1101, $43, %0101
.db $a3, %1110, $9d, %0100
.db $a3, %1111, $3d, %0101
.db $a4, %0000, $04, %0001
.db $a4, %0001, $04, %0001
.db $a4, %0010, $0a, %0001
.db $a4, %0011, $0a, %0001
.db $a4, %0100, $a4, %0100
.db $a4, %0101, $44, %0101
.db $a4, %0110, $9e, %0100
.db $a4, %0111, $3e, %0101
.db $a4, %1000, $04, %0001
.db $a4, %1001, $04, %0001
.db $a4, %1010, $0a, %0001
.db $a4, %1011, $0a, %0001
.db $a4, %1100, $a4, %0100
.db $a4, %1101, $44, %0101
.db $a4, %1110, $9e, %0100
.db $a4, %1111, $3e, %0101
.db $a5, %0000, $05, %0001
.db $a5, %0001, $05, %0001
.db $a5, %0010, $0b, %0001
.db $a5, %0011, $0b, %0001
.db $a5, %0100, $a5, %0100
.db $a5, %0101, $45, %0101
.db $a5, %0110, $9f, %0100
.db $a5, %0111, $3f, %0101
.db $a5, %1000, $05, %0001
.db $a5, %1001, $05, %0001
.db $a5, %1010, $0b, %0001
.db $a5, %1011, $0b, %0001
.db $a5, %1100, $a5, %0100
.db $a5, %1101, $45, %0101
.db $a5, %1110, $9f, %0100
.db $a5, %1111, $3f, %0101
.db $a6, %0000, $06, %0001
.db $a6, %0001, $06, %0001
.db $a6, %0010, $0c, %0001
.db $a6, %0011, $0c, %0001
.db $a6, %0100, $a6, %0100
.db $a6, %0101, $46, %0101
.db $a6, %0110, $a0, %0100
.db $a6, %0111, $40, %0101
.db $a6, %1000, $06, %0001
.db $a6, %1001, $06, %0001
.db $a6, %1010, $0c, %0001
.db $a6, %1011, $0c, %0001
.db $a6, %1100, $a6, %0100
.db $a6, %1101, $46, %0101
.db $a6, %1110, $a0, %0100
.db $a6, %1111, $40, %0101
.db $a7, %0000, $07, %0001
.db $a7, %0001, $07, %0001
.db $a7, %0010, $0d, %0001
.db $a7, %0011, $0d, %0001
.db $a7, %0100, $a7, %0100
.db $a7, %0101, $47, %0101
.db $a7, %0110, $a1, %0100
.db $a7, %0111, $41, %0101
.db $a7, %1000, $07, %0001
.db $a7, %1001, $07, %0001
.db $a7, %1010, $0d, %0001
.db $a7, %1011, $0d, %0001
.db $a7, %1100, $a7, %0100
.db $a7, %1101, $47, %0101
.db $a7, %1110, $a1, %0100
.db $a7, %1111, $41, %0101
.db $a8, %0000, $08, %0001
.db $a8, %0001, $08, %0001
.db $a8, %0010, $0e, %0001
.db $a8, %0011, $0e, %0001
.db $a8, %0100, $a8, %0100
.db $a8, %0101, $48, %0101
.db $a8, %0110, $a2, %0100
.db $a8, %0111, $42, %0101
.db $a8, %1000, $08, %0001
.db $a8, %1001, $08, %0001
.db $a8, %1010, $0e, %0001
.db $a8, %1011, $0e, %0001
.db $a8, %1100, $a8, %0100
.db $a8, %1101, $48, %0101
.db $a8, %1110, $a2, %0100
.db $a8, %1111, $42, %0101
.db $a9, %0000, $09, %0001
.db $a9, %0001, $09, %0001
.db $a9, %0010, $0f, %0001
.db $a9, %0011, $0f, %0001
.db $a9, %0100, $a9, %0100
.db $a9, %0101, $49, %0101
.db $a9, %0110, $a3, %0100
.db $a9, %0111, $43, %0101
.db $a9, %1000, $09, %0001
.db $a9, %1001, $09, %0001
.db $a9, %1010, $0f, %0001
.db $a9, %1011, $0f, %0001
.db $a9, %1100, $a9, %0100
.db $a9, %1101, $49, %0101
.db $a9, %1110, $a3, %0100
.db $a9, %1111, $43, %0101
.db $aa, %0000, $10, %0001
.db $aa, %0001, $10, %0001
.db $aa, %0010, $10, %0001
.db $aa, %0011, $10, %0001
.db $aa, %0100, $aa, %0100
.db $aa, %0101, $4a, %0101
.db $aa, %0110, $a4, %0100
.db $aa, %0111, $44, %0101
.db $aa, %1000, $10, %0001
.db $aa, %1001, $10, %0001
.db $aa, %1010, $10, %0001
.db $aa, %1011, $10, %0001
.db $aa, %1100, $aa, %0100
.db $aa, %1101, $4a, %0101
.db $aa, %1110, $a4, %0100
.db $aa, %1111, $44, %0101
.db $ab, %0000, $11, %0001
.db $ab, %0001, $11, %0001
.db $ab, %0010, $11, %0001
.db $ab, %0011, $11, %0001
.db $ab, %0100, $ab, %0100
.db $ab, %0101, $4b, %0101
.db $ab, %0110, $a5, %0100
.db $ab, %0111, $45, %0101
.db $ab, %1000, $11, %0001
.db $ab, %1001, $11, %0001
.db $ab, %1010, $11, %0001
.db $ab, %1011, $11, %0001
.db $ab, %1100, $ab, %0100
.db $ab, %1101, $4b, %0101
.db $ab, %1110, $a5, %0100
.db $ab, %1111, $45, %0101
.db $ac, %0000, $12, %0001
.db $ac, %0001, $12, %0001
.db $ac, %0010, $12, %0001
.db $ac, %0011, $12, %0001
.db $ac, %0100, $ac, %0100
.db $ac, %0101, $4c, %0101
.db $ac, %0110, $a6, %0100
.db $ac, %0111, $46, %0101
.db $ac, %1000, $12, %0001
.db $ac, %1001, $12, %0001
.db $ac, %1010, $12, %0001
.db $ac, %1011, $12, %0001
.db $ac, %1100, $ac, %0100
.db $ac, %1101, $4c, %0101
.db $ac, %1110, $a6, %0100
.db $ac, %1111, $46, %0101
.db $ad, %0000, $13, %0001
.db $ad, %0001, $13, %0001
.db $ad, %0010, $13, %0001
.db $ad, %0011, $13, %0001
.db $ad, %0100, $ad, %0100
.db $ad, %0101, $4d, %0101
.db $ad, %0110, $a7, %0100
.db $ad, %0111, $47, %0101
.db $ad, %1000, $13, %0001
.db $ad, %1001, $13, %0001
.db $ad, %1010, $13, %0001
.db $ad, %1011, $13, %0001
.db $ad, %1100, $ad, %0100
.db $ad, %1101, $4d, %0101
.db $ad, %1110, $a7, %0100
.db $ad, %1111, $47, %0101
.db $ae, %0000, $14, %0001
.db $ae, %0001, $14, %0001
.db $ae, %0010, $14, %0001
.db $ae, %0011, $14, %0001
.db $ae, %0100, $ae, %0100
.db $ae, %0101, $4e, %0101
.db $ae, %0110, $a8, %0100
.db $ae, %0111, $48, %0101
.db $ae, %1000, $14, %0001
.db $ae, %1001, $14, %0001
.db $ae, %1010, $14, %0001
.db $ae, %1011, $14, %0001
.db $ae, %1100, $ae, %0100
.db $ae, %1101, $4e, %0101
.db $ae, %1110, $a8, %0100
.db $ae, %1111, $48, %0101
.db $af, %0000, $15, %0001
.db $af, %0001, $15, %0001
.db $af, %0010, $15, %0001
.db $af, %0011, $15, %0001
.db $af, %0100, $af, %0100
.db $af, %0101, $4f, %0101
.db $af, %0110, $a9, %0100
.db $af, %0111, $49, %0101
.db $af, %1000, $15, %0001
.db $af, %1001, $15, %0001
.db $af, %1010, $15, %0001
.db $af, %1011, $15, %0001
.db $af, %1100, $af, %0100
.db $af, %1101, $4f, %0101
.db $af, %1110, $a9, %0100
.db $af, %1111, $49, %0101
.db $b0, %0000, $10, %0001
.db $b0, %0001, $10, %0001
.db $b0, %0010, $16, %0001
.db $b0, %0011, $16, %0001
.db $b0, %0100, $b0, %0100
.db $b0, %0101, $50, %0101
.db $b0, %0110, $aa, %0100
.db $b0, %0111, $4a, %0101
.db $b0, %1000, $10, %0001
.db $b0, %1001, $10, %0001
.db $b0, %1010, $16, %0001
.db $b0, %1011, $16, %0001
.db $b0, %1100, $b0, %0100
.db $b0, %1101, $50, %0101
.db $b0, %1110, $aa, %0100
.db $b0, %1111, $4a, %0101
.db $b1, %0000, $11, %0001
.db $b1, %0001, $11, %0001
.db $b1, %0010, $17, %0001
.db $b1, %0011, $17, %0001
.db $b1, %0100, $b1, %0100
.db $b1, %0101, $51, %0101
.db $b1, %0110, $ab, %0100
.db $b1, %0111, $4b, %0101
.db $b1, %1000, $11, %0001
.db $b1, %1001, $11, %0001
.db $b1, %1010, $17, %0001
.db $b1, %1011, $17, %0001
.db $b1, %1100, $b1, %0100
.db $b1, %1101, $51, %0101
.db $b1, %1110, $ab, %0100
.db $b1, %1111, $4b, %0101
.db $b2, %0000, $12, %0001
.db $b2, %0001, $12, %0001
.db $b2, %0010, $18, %0001
.db $b2, %0011, $18, %0001
.db $b2, %0100, $b2, %0100
.db $b2, %0101, $52, %0101
.db $b2, %0110, $ac, %0100
.db $b2, %0111, $4c, %0101
.db $b2, %1000, $12, %0001
.db $b2, %1001, $12, %0001
.db $b2, %1010, $18, %0001
.db $b2, %1011, $18, %0001
.db $b2, %1100, $b2, %0100
.db $b2, %1101, $52, %0101
.db $b2, %1110, $ac, %0100
.db $b2, %1111, $4c, %0101
.db $b3, %0000, $13, %0001
.db $b3, %0001, $13, %0001
.db $b3, %0010, $19, %0001
.db $b3, %0011, $19, %0001
.db $b3, %0100, $b3, %0100
.db $b3, %0101, $53, %0101
.db $b3, %0110, $ad, %0100
.db $b3, %0111, $4d, %0101
.db $b3, %1000, $13, %0001
.db $b3, %1001, $13, %0001
.db $b3, %1010, $19, %0001
.db $b3, %1011, $19, %0001
.db $b3, %1100, $b3, %0100
.db $b3, %1101, $53, %0101
.db $b3, %1110, $ad, %0100
.db $b3, %1111, $4d, %0101
.db $b4, %0000, $14, %0001
.db $b4, %0001, $14, %0001
.db $b4, %0010, $1a, %0001
.db $b4, %0011, $1a, %0001
.db $b4, %0100, $b4, %0100
.db $b4, %0101, $54, %0101
.db $b4, %0110, $ae, %0100
.db $b4, %0111, $4e, %0101
.db $b4, %1000, $14, %0001
.db $b4, %1001, $14, %0001
.db $b4, %1010, $1a, %0001
.db $b4, %1011, $1a, %0001
.db $b4, %1100, $b4, %0100
.db $b4, %1101, $54, %0101
.db $b4, %1110, $ae, %0100
.db $b4, %1111, $4e, %0101
.db $b5, %0000, $15, %0001
.db $b5, %0001, $15, %0001
.db $b5, %0010, $1b, %0001
.db $b5, %0011, $1b, %0001
.db $b5, %0100, $b5, %0100
.db $b5, %0101, $55, %0101
.db $b5, %0110, $af, %0100
.db $b5, %0111, $4f, %0101
.db $b5, %1000, $15, %0001
.db $b5, %1001, $15, %0001
.db $b5, %1010, $1b, %0001
.db $b5, %1011, $1b, %0001
.db $b5, %1100, $b5, %0100
.db $b5, %1101, $55, %0101
.db $b5, %1110, $af, %0100
.db $b5, %1111, $4f, %0101
.db $b6, %0000, $16, %0001
.db $b6, %0001, $16, %0001
.db $b6, %0010, $1c, %0001
.db $b6, %0011, $1c, %0001
.db $b6, %0100, $b6, %0100
.db $b6, %0101, $56, %0101
.db $b6, %0110, $b0, %0100
.db $b6, %0111, $50, %0101
.db $b6, %1000, $16, %0001
.db $b6, %1001, $16, %0001
.db $b6, %1010, $1c, %0001
.db $b6, %1011, $1c, %0001
.db $b6, %1100, $b6, %0100
.db $b6, %1101, $56, %0101
.db $b6, %1110, $b0, %0100
.db $b6, %1111, $50, %0101
.db $b7, %0000, $17, %0001
.db $b7, %0001, $17, %0001
.db $b7, %0010, $1d, %0001
.db $b7, %0011, $1d, %0001
.db $b7, %0100, $b7, %0100
.db $b7, %0101, $57, %0101
.db $b7, %0110, $b1, %0100
.db $b7, %0111, $51, %0101
.db $b7, %1000, $17, %0001
.db $b7, %1001, $17, %0001
.db $b7, %1010, $1d, %0001
.db $b7, %1011, $1d, %0001
.db $b7, %1100, $b7, %0100
.db $b7, %1101, $57, %0101
.db $b7, %1110, $b1, %0100
.db $b7, %1111, $51, %0101
.db $b8, %0000, $18, %0001
.db $b8, %0001, $18, %0001
.db $b8, %0010, $1e, %0001
.db $b8, %0011, $1e, %0001
.db $b8, %0100, $b8, %0100
.db $b8, %0101, $58, %0101
.db $b8, %0110, $b2, %0100
.db $b8, %0111, $52, %0101
.db $b8, %1000, $18, %0001
.db $b8, %1001, $18, %0001
.db $b8, %1010, $1e, %0001
.db $b8, %1011, $1e, %0001
.db $b8, %1100, $b8, %0100
.db $b8, %1101, $58, %0101
.db $b8, %1110, $b2, %0100
.db $b8, %1111, $52, %0101
.db $b9, %0000, $19, %0001
.db $b9, %0001, $19, %0001
.db $b9, %0010, $1f, %0001
.db $b9, %0011, $1f, %0001
.db $b9, %0100, $b9, %0100
.db $b9, %0101, $59, %0101
.db $b9, %0110, $b3, %0100
.db $b9, %0111, $53, %0101
.db $b9, %1000, $19, %0001
.db $b9, %1001, $19, %0001
.db $b9, %1010, $1f, %0001
.db $b9, %1011, $1f, %0001
.db $b9, %1100, $b9, %0100
.db $b9, %1101, $59, %0101
.db $b9, %1110, $b3, %0100
.db $b9, %1111, $53, %0101
.db $ba, %0000, $20, %0001
.db $ba, %0001, $20, %0001
.db $ba, %0010, $20, %0001
.db $ba, %0011, $20, %0001
.db $ba, %0100, $ba, %0100
.db $ba, %0101, $5a, %0101
.db $ba, %0110, $b4, %0100
.db $ba, %0111, $54, %0101
.db $ba, %1000, $20, %0001
.db $ba, %1001, $20, %0001
.db $ba, %1010, $20, %0001
.db $ba, %1011, $20, %0001
.db $ba, %1100, $ba, %0100
.db $ba, %1101, $5a, %0101
.db $ba, %1110, $b4, %0100
.db $ba, %1111, $54, %0101
.db $bb, %0000, $21, %0001
.db $bb, %0001, $21, %0001
.db $bb, %0010, $21, %0001
.db $bb, %0011, $21, %0001
.db $bb, %0100, $bb, %0100
.db $bb, %0101, $5b, %0101
.db $bb, %0110, $b5, %0100
.db $bb, %0111, $55, %0101
.db $bb, %1000, $21, %0001
.db $bb, %1001, $21, %0001
.db $bb, %1010, $21, %0001
.db $bb, %1011, $21, %0001
.db $bb, %1100, $bb, %0100
.db $bb, %1101, $5b, %0101
.db $bb, %1110, $b5, %0100
.db $bb, %1111, $55, %0101
.db $bc, %0000, $22, %0001
.db $bc, %0001, $22, %0001
.db $bc, %0010, $22, %0001
.db $bc, %0011, $22, %0001
.db $bc, %0100, $bc, %0100
.db $bc, %0101, $5c, %0101
.db $bc, %0110, $b6, %0100
.db $bc, %0111, $56, %0101
.db $bc, %1000, $22, %0001
.db $bc, %1001, $22, %0001
.db $bc, %1010, $22, %0001
.db $bc, %1011, $22, %0001
.db $bc, %1100, $bc, %0100
.db $bc, %1101, $5c, %0101
.db $bc, %1110, $b6, %0100
.db $bc, %1111, $56, %0101
.db $bd, %0000, $23, %0001
.db $bd, %0001, $23, %0001
.db $bd, %0010, $23, %0001
.db $bd, %0011, $23, %0001
.db $bd, %0100, $bd, %0100
.db $bd, %0101, $5d, %0101
.db $bd, %0110, $b7, %0100
.db $bd, %0111, $57, %0101
.db $bd, %1000, $23, %0001
.db $bd, %1001, $23, %0001
.db $bd, %1010, $23, %0001
.db $bd, %1011, $23, %0001
.db $bd, %1100, $bd, %0100
.db $bd, %1101, $5d, %0101
.db $bd, %1110, $b7, %0100
.db $bd, %1111, $57, %0101
.db $be, %0000, $24, %0001
.db $be, %0001, $24, %0001
.db $be, %0010, $24, %0001
.db $be, %0011, $24, %0001
.db $be, %0100, $be, %0100
.db $be, %0101, $5e, %0101
.db $be, %0110, $b8, %0100
.db $be, %0111, $58, %0101
.db $be, %1000, $24, %0001
.db $be, %1001, $24, %0001
.db $be, %1010, $24, %0001
.db $be, %1011, $24, %0001
.db $be, %1100, $be, %0100
.db $be, %1101, $5e, %0101
.db $be, %1110, $b8, %0100
.db $be, %1111, $58, %0101
.db $bf, %0000, $25, %0001
.db $bf, %0001, $25, %0001
.db $bf, %0010, $25, %0001
.db $bf, %0011, $25, %0001
.db $bf, %0100, $bf, %0100
.db $bf, %0101, $5f, %0101
.db $bf, %0110, $b9, %0100
.db $bf, %0111, $59, %0101
.db $bf, %1000, $25, %0001
.db $bf, %1001, $25, %0001
.db $bf, %1010, $25, %0001
.db $bf, %1011, $25, %0001
.db $bf, %1100, $bf, %0100
.db $bf, %1101, $5f, %0101
.db $bf, %1110, $b9, %0100
.db $bf, %1111, $59, %0101
.db $c0, %0000, $20, %0001
.db $c0, %0001, $20, %0001
.db $c0, %0010, $26, %0001
.db $c0, %0011, $26, %0001
.db $c0, %0100, $c0, %0100
.db $c0, %0101, $60, %0101
.db $c0, %0110, $ba, %0100
.db $c0, %0111, $5a, %0101
.db $c0, %1000, $20, %0001
.db $c0, %1001, $20, %0001
.db $c0, %1010, $26, %0001
.db $c0, %1011, $26, %0001
.db $c0, %1100, $c0, %0100
.db $c0, %1101, $60, %0101
.db $c0, %1110, $ba, %0100
.db $c0, %1111, $5a, %0101
.db $c1, %0000, $21, %0001
.db $c1, %0001, $21, %0001
.db $c1, %0010, $27, %0001
.db $c1, %0011, $27, %0001
.db $c1, %0100, $c1, %0100
.db $c1, %0101, $61, %0101
.db $c1, %0110, $bb, %0100
.db $c1, %0111, $5b, %0101
.db $c1, %1000, $21, %0001
.db $c1, %1001, $21, %0001
.db $c1, %1010, $27, %0001
.db $c1, %1011, $27, %0001
.db $c1, %1100, $c1, %0100
.db $c1, %1101, $61, %0101
.db $c1, %1110, $bb, %0100
.db $c1, %1111, $5b, %0101
.db $c2, %0000, $22, %0001
.db $c2, %0001, $22, %0001
.db $c2, %0010, $28, %0001
.db $c2, %0011, $28, %0001
.db $c2, %0100, $c2, %0100
.db $c2, %0101, $62, %0101
.db $c2, %0110, $bc, %0100
.db $c2, %0111, $5c, %0101
.db $c2, %1000, $22, %0001
.db $c2, %1001, $22, %0001
.db $c2, %1010, $28, %0001
.db $c2, %1011, $28, %0001
.db $c2, %1100, $c2, %0100
.db $c2, %1101, $62, %0101
.db $c2, %1110, $bc, %0100
.db $c2, %1111, $5c, %0101
.db $c3, %0000, $23, %0001
.db $c3, %0001, $23, %0001
.db $c3, %0010, $29, %0001
.db $c3, %0011, $29, %0001
.db $c3, %0100, $c3, %0100
.db $c3, %0101, $63, %0101
.db $c3, %0110, $bd, %0100
.db $c3, %0111, $5d, %0101
.db $c3, %1000, $23, %0001
.db $c3, %1001, $23, %0001
.db $c3, %1010, $29, %0001
.db $c3, %1011, $29, %0001
.db $c3, %1100, $c3, %0100
.db $c3, %1101, $63, %0101
.db $c3, %1110, $bd, %0100
.db $c3, %1111, $5d, %0101
.db $c4, %0000, $24, %0001
.db $c4, %0001, $24, %0001
.db $c4, %0010, $2a, %0001
.db $c4, %0011, $2a, %0001
.db $c4, %0100, $c4, %0100
.db $c4, %0101, $64, %0101
.db $c4, %0110, $be, %0100
.db $c4, %0111, $5e, %0101
.db $c4, %1000, $24, %0001
.db $c4, %1001, $24, %0001
.db $c4, %1010, $2a, %0001
.db $c4, %1011, $2a, %0001
.db $c4, %1100, $c4, %0100
.db $c4, %1101, $64, %0101
.db $c4, %1110, $be, %0100
.db $c4, %1111, $5e, %0101
.db $c5, %0000, $25, %0001
.db $c5, %0001, $25, %0001
.db $c5, %0010, $2b, %0001
.db $c5, %0011, $2b, %0001
.db $c5, %0100, $c5, %0100
.db $c5, %0101, $65, %0101
.db $c5, %0110, $bf, %0100
.db $c5, %0111, $5f, %0101
.db $c5, %1000, $25, %0001
.db $c5, %1001, $25, %0001
.db $c5, %1010, $2b, %0001
.db $c5, %1011, $2b, %0001
.db $c5, %1100, $c5, %0100
.db $c5, %1101, $65, %0101
.db $c5, %1110, $bf, %0100
.db $c5, %1111, $5f, %0101
.db $c6, %0000, $26, %0001
.db $c6, %0001, $26, %0001
.db $c6, %0010, $2c, %0001
.db $c6, %0011, $2c, %0001
.db $c6, %0100, $c6, %0100
.db $c6, %0101, $66, %0101
.db $c6, %0110, $c0, %0100
.db $c6, %0111, $60, %0101
.db $c6, %1000, $26, %0001
.db $c6, %1001, $26, %0001
.db $c6, %1010, $2c, %0001
.db $c6, %1011, $2c, %0001
.db $c6, %1100, $c6, %0100
.db $c6, %1101, $66, %0101
.db $c6, %1110, $c0, %0100
.db $c6, %1111, $60, %0101
.db $c7, %0000, $27, %0001
.db $c7, %0001, $27, %0001
.db $c7, %0010, $2d, %0001
.db $c7, %0011, $2d, %0001
.db $c7, %0100, $c7, %0100
.db $c7, %0101, $67, %0101
.db $c7, %0110, $c1, %0100
.db $c7, %0111, $61, %0101
.db $c7, %1000, $27, %0001
.db $c7, %1001, $27, %0001
.db $c7, %1010, $2d, %0001
.db $c7, %1011, $2d, %0001
.db $c7, %1100, $c7, %0100
.db $c7, %1101, $67, %0101
.db $c7, %1110, $c1, %0100
.db $c7, %1111, $61, %0101
.db $c8, %0000, $28, %0001
.db $c8, %0001, $28, %0001
.db $c8, %0010, $2e, %0001
.db $c8, %0011, $2e, %0001
.db $c8, %0100, $c8, %0100
.db $c8, %0101, $68, %0101
.db $c8, %0110, $c2, %0100
.db $c8, %0111, $62, %0101
.db $c8, %1000, $28, %0001
.db $c8, %1001, $28, %0001
.db $c8, %1010, $2e, %0001
.db $c8, %1011, $2e, %0001
.db $c8, %1100, $c8, %0100
.db $c8, %1101, $68, %0101
.db $c8, %1110, $c2, %0100
.db $c8, %1111, $62, %0101
.db $c9, %0000, $29, %0001
.db $c9, %0001, $29, %0001
.db $c9, %0010, $2f, %0001
.db $c9, %0011, $2f, %0001
.db $c9, %0100, $c9, %0100
.db $c9, %0101, $69, %0101
.db $c9, %0110, $c3, %0100
.db $c9, %0111, $63, %0101
.db $c9, %1000, $29, %0001
.db $c9, %1001, $29, %0001
.db $c9, %1010, $2f, %0001
.db $c9, %1011, $2f, %0001
.db $c9, %1100, $c9, %0100
.db $c9, %1101, $69, %0101
.db $c9, %1110, $c3, %0100
.db $c9, %1111, $63, %0101
.db $ca, %0000, $30, %0001
.db $ca, %0001, $30, %0001
.db $ca, %0010, $30, %0001
.db $ca, %0011, $30, %0001
.db $ca, %0100, $ca, %0100
.db $ca, %0101, $6a, %0101
.db $ca, %0110, $c4, %0100
.db $ca, %0111, $64, %0101
.db $ca, %1000, $30, %0001
.db $ca, %1001, $30, %0001
.db $ca, %1010, $30, %0001
.db $ca, %1011, $30, %0001
.db $ca, %1100, $ca, %0100
.db $ca, %1101, $6a, %0101
.db $ca, %1110, $c4, %0100
.db $ca, %1111, $64, %0101
.db $cb, %0000, $31, %0001
.db $cb, %0001, $31, %0001
.db $cb, %0010, $31, %0001
.db $cb, %0011, $31, %0001
.db $cb, %0100, $cb, %0100
.db $cb, %0101, $6b, %0101
.db $cb, %0110, $c5, %0100
.db $cb, %0111, $65, %0101
.db $cb, %1000, $31, %0001
.db $cb, %1001, $31, %0001
.db $cb, %1010, $31, %0001
.db $cb, %1011, $31, %0001
.db $cb, %1100, $cb, %0100
.db $cb, %1101, $6b, %0101
.db $cb, %1110, $c5, %0100
.db $cb, %1111, $65, %0101
.db $cc, %0000, $32, %0001
.db $cc, %0001, $32, %0001
.db $cc, %0010, $32, %0001
.db $cc, %0011, $32, %0001
.db $cc, %0100, $cc, %0100
.db $cc, %0101, $6c, %0101
.db $cc, %0110, $c6, %0100
.db $cc, %0111, $66, %0101
.db $cc, %1000, $32, %0001
.db $cc, %1001, $32, %0001
.db $cc, %1010, $32, %0001
.db $cc, %1011, $32, %0001
.db $cc, %1100, $cc, %0100
.db $cc, %1101, $6c, %0101
.db $cc, %1110, $c6, %0100
.db $cc, %1111, $66, %0101
.db $cd, %0000, $33, %0001
.db $cd, %0001, $33, %0001
.db $cd, %0010, $33, %0001
.db $cd, %0011, $33, %0001
.db $cd, %0100, $cd, %0100
.db $cd, %0101, $6d, %0101
.db $cd, %0110, $c7, %0100
.db $cd, %0111, $67, %0101
.db $cd, %1000, $33, %0001
.db $cd, %1001, $33, %0001
.db $cd, %1010, $33, %0001
.db $cd, %1011, $33, %0001
.db $cd, %1100, $cd, %0100
.db $cd, %1101, $6d, %0101
.db $cd, %1110, $c7, %0100
.db $cd, %1111, $67, %0101
.db $ce, %0000, $34, %0001
.db $ce, %0001, $34, %0001
.db $ce, %0010, $34, %0001
.db $ce, %0011, $34, %0001
.db $ce, %0100, $ce, %0100
.db $ce, %0101, $6e, %0101
.db $ce, %0110, $c8, %0100
.db $ce, %0111, $68, %0101
.db $ce, %1000, $34, %0001
.db $ce, %1001, $34, %0001
.db $ce, %1010, $34, %0001
.db $ce, %1011, $34, %0001
.db $ce, %1100, $ce, %0100
.db $ce, %1101, $6e, %0101
.db $ce, %1110, $c8, %0100
.db $ce, %1111, $68, %0101
.db $cf, %0000, $35, %0001
.db $cf, %0001, $35, %0001
.db $cf, %0010, $35, %0001
.db $cf, %0011, $35, %0001
.db $cf, %0100, $cf, %0100
.db $cf, %0101, $6f, %0101
.db $cf, %0110, $c9, %0100
.db $cf, %0111, $69, %0101
.db $cf, %1000, $35, %0001
.db $cf, %1001, $35, %0001
.db $cf, %1010, $35, %0001
.db $cf, %1011, $35, %0001
.db $cf, %1100, $cf, %0100
.db $cf, %1101, $6f, %0101
.db $cf, %1110, $c9, %0100
.db $cf, %1111, $69, %0101
.db $d0, %0000, $30, %0001
.db $d0, %0001, $30, %0001
.db $d0, %0010, $36, %0001
.db $d0, %0011, $36, %0001
.db $d0, %0100, $d0, %0100
.db $d0, %0101, $70, %0101
.db $d0, %0110, $ca, %0100
.db $d0, %0111, $6a, %0101
.db $d0, %1000, $30, %0001
.db $d0, %1001, $30, %0001
.db $d0, %1010, $36, %0001
.db $d0, %1011, $36, %0001
.db $d0, %1100, $d0, %0100
.db $d0, %1101, $70, %0101
.db $d0, %1110, $ca, %0100
.db $d0, %1111, $6a, %0101
.db $d1, %0000, $31, %0001
.db $d1, %0001, $31, %0001
.db $d1, %0010, $37, %0001
.db $d1, %0011, $37, %0001
.db $d1, %0100, $d1, %0100
.db $d1, %0101, $71, %0101
.db $d1, %0110, $cb, %0100
.db $d1, %0111, $6b, %0101
.db $d1, %1000, $31, %0001
.db $d1, %1001, $31, %0001
.db $d1, %1010, $37, %0001
.db $d1, %1011, $37, %0001
.db $d1, %1100, $d1, %0100
.db $d1, %1101, $71, %0101
.db $d1, %1110, $cb, %0100
.db $d1, %1111, $6b, %0101
.db $d2, %0000, $32, %0001
.db $d2, %0001, $32, %0001
.db $d2, %0010, $38, %0001
.db $d2, %0011, $38, %0001
.db $d2, %0100, $d2, %0100
.db $d2, %0101, $72, %0101
.db $d2, %0110, $cc, %0100
.db $d2, %0111, $6c, %0101
.db $d2, %1000, $32, %0001
.db $d2, %1001, $32, %0001
.db $d2, %1010, $38, %0001
.db $d2, %1011, $38, %0001
.db $d2, %1100, $d2, %0100
.db $d2, %1101, $72, %0101
.db $d2, %1110, $cc, %0100
.db $d2, %1111, $6c, %0101
.db $d3, %0000, $33, %0001
.db $d3, %0001, $33, %0001
.db $d3, %0010, $39, %0001
.db $d3, %0011, $39, %0001
.db $d3, %0100, $d3, %0100
.db $d3, %0101, $73, %0101
.db $d3, %0110, $cd, %0100
.db $d3, %0111, $6d, %0101
.db $d3, %1000, $33, %0001
.db $d3, %1001, $33, %0001
.db $d3, %1010, $39, %0001
.db $d3, %1011, $39, %0001
.db $d3, %1100, $d3, %0100
.db $d3, %1101, $73, %0101
.db $d3, %1110, $cd, %0100
.db $d3, %1111, $6d, %0101
.db $d4, %0000, $34, %0001
.db $d4, %0001, $34, %0001
.db $d4, %0010, $3a, %0001
.db $d4, %0011, $3a, %0001
.db $d4, %0100, $d4, %0100
.db $d4, %0101, $74, %0101
.db $d4, %0110, $ce, %0100
.db $d4, %0111, $6e, %0101
.db $d4, %1000, $34, %0001
.db $d4, %1001, $34, %0001
.db $d4, %1010, $3a, %0001
.db $d4, %1011, $3a, %0001
.db $d4, %1100, $d4, %0100
.db $d4, %1101, $74, %0101
.db $d4, %1110, $ce, %0100
.db $d4, %1111, $6e, %0101
.db $d5, %0000, $35, %0001
.db $d5, %0001, $35, %0001
.db $d5, %0010, $3b, %0001
.db $d5, %0011, $3b, %0001
.db $d5, %0100, $d5, %0100
.db $d5, %0101, $75, %0101
.db $d5, %0110, $cf, %0100
.db $d5, %0111, $6f, %0101
.db $d5, %1000, $35, %0001
.db $d5, %1001, $35, %0001
.db $d5, %1010, $3b, %0001
.db $d5, %1011, $3b, %0001
.db $d5, %1100, $d5, %0100
.db $d5, %1101, $75, %0101
.db $d5, %1110, $cf, %0100
.db $d5, %1111, $6f, %0101
.db $d6, %0000, $36, %0001
.db $d6, %0001, $36, %0001
.db $d6, %0010, $3c, %0001
.db $d6, %0011, $3c, %0001
.db $d6, %0100, $d6, %0100
.db $d6, %0101, $76, %0101
.db $d6, %0110, $d0, %0100
.db $d6, %0111, $70, %0101
.db $d6, %1000, $36, %0001
.db $d6, %1001, $36, %0001
.db $d6, %1010, $3c, %0001
.db $d6, %1011, $3c, %0001
.db $d6, %1100, $d6, %0100
.db $d6, %1101, $76, %0101
.db $d6, %1110, $d0, %0100
.db $d6, %1111, $70, %0101
.db $d7, %0000, $37, %0001
.db $d7, %0001, $37, %0001
.db $d7, %0010, $3d, %0001
.db $d7, %0011, $3d, %0001
.db $d7, %0100, $d7, %0100
.db $d7, %0101, $77, %0101
.db $d7, %0110, $d1, %0100
.db $d7, %0111, $71, %0101
.db $d7, %1000, $37, %0001
.db $d7, %1001, $37, %0001
.db $d7, %1010, $3d, %0001
.db $d7, %1011, $3d, %0001
.db $d7, %1100, $d7, %0100
.db $d7, %1101, $77, %0101
.db $d7, %1110, $d1, %0100
.db $d7, %1111, $71, %0101
.db $d8, %0000, $38, %0001
.db $d8, %0001, $38, %0001
.db $d8, %0010, $3e, %0001
.db $d8, %0011, $3e, %0001
.db $d8, %0100, $d8, %0100
.db $d8, %0101, $78, %0101
.db $d8, %0110, $d2, %0100
.db $d8, %0111, $72, %0101
.db $d8, %1000, $38, %0001
.db $d8, %1001, $38, %0001
.db $d8, %1010, $3e, %0001
.db $d8, %1011, $3e, %0001
.db $d8, %1100, $d8, %0100
.db $d8, %1101, $78, %0101
.db $d8, %1110, $d2, %0100
.db $d8, %1111, $72, %0101
.db $d9, %0000, $39, %0001
.db $d9, %0001, $39, %0001
.db $d9, %0010, $3f, %0001
.db $d9, %0011, $3f, %0001
.db $d9, %0100, $d9, %0100
.db $d9, %0101, $79, %0101
.db $d9, %0110, $d3, %0100
.db $d9, %0111, $73, %0101
.db $d9, %1000, $39, %0001
.db $d9, %1001, $39, %0001
.db $d9, %1010, $3f, %0001
.db $d9, %1011, $3f, %0001
.db $d9, %1100, $d9, %0100
.db $d9, %1101, $79, %0101
.db $d9, %1110, $d3, %0100
.db $d9, %1111, $73, %0101
.db $da, %0000, $40, %0001
.db $da, %0001, $40, %0001
.db $da, %0010, $40, %0001
.db $da, %0011, $40, %0001
.db $da, %0100, $da, %0100
.db $da, %0101, $7a, %0101
.db $da, %0110, $d4, %0100
.db $da, %0111, $74, %0101
.db $da, %1000, $40, %0001
.db $da, %1001, $40, %0001
.db $da, %1010, $40, %0001
.db $da, %1011, $40, %0001
.db $da, %1100, $da, %0100
.db $da, %1101, $7a, %0101
.db $da, %1110, $d4, %0100
.db $da, %1111, $74, %0101
.db $db, %0000, $41, %0001
.db $db, %0001, $41, %0001
.db $db, %0010, $41, %0001
.db $db, %0011, $41, %0001
.db $db, %0100, $db, %0100
.db $db, %0101, $7b, %0101
.db $db, %0110, $d5, %0100
.db $db, %0111, $75, %0101
.db $db, %1000, $41, %0001
.db $db, %1001, $41, %0001
.db $db, %1010, $41, %0001
.db $db, %1011, $41, %0001
.db $db, %1100, $db, %0100
.db $db, %1101, $7b, %0101
.db $db, %1110, $d5, %0100
.db $db, %1111, $75, %0101
.db $dc, %0000, $42, %0001
.db $dc, %0001, $42, %0001
.db $dc, %0010, $42, %0001
.db $dc, %0011, $42, %0001
.db $dc, %0100, $dc, %0100
.db $dc, %0101, $7c, %0101
.db $dc, %0110, $d6, %0100
.db $dc, %0111, $76, %0101
.db $dc, %1000, $42, %0001
.db $dc, %1001, $42, %0001
.db $dc, %1010, $42, %0001
.db $dc, %1011, $42, %0001
.db $dc, %1100, $dc, %0100
.db $dc, %1101, $7c, %0101
.db $dc, %1110, $d6, %0100
.db $dc, %1111, $76, %0101
.db $dd, %0000, $43, %0001
.db $dd, %0001, $43, %0001
.db $dd, %0010, $43, %0001
.db $dd, %0011, $43, %0001
.db $dd, %0100, $dd, %0100
.db $dd, %0101, $7d, %0101
.db $dd, %0110, $d7, %0100
.db $dd, %0111, $77, %0101
.db $dd, %1000, $43, %0001
.db $dd, %1001, $43, %0001
.db $dd, %1010, $43, %0001
.db $dd, %1011, $43, %0001
.db $dd, %1100, $dd, %0100
.db $dd, %1101, $7d, %0101
.db $dd, %1110, $d7, %0100
.db $dd, %1111, $77, %0101
.db $de, %0000, $44, %0001
.db $de, %0001, $44, %0001
.db $de, %0010, $44, %0001
.db $de, %0011, $44, %0001
.db $de, %0100, $de, %0100
.db $de, %0101, $7e, %0101
.db $de, %0110, $d8, %0100
.db $de, %0111, $78, %0101
.db $de, %1000, $44, %0001
.db $de, %1001, $44, %0001
.db $de, %1010, $44, %0001
.db $de, %1011, $44, %0001
.db $de, %1100, $de, %0100
.db $de, %1101, $7e, %0101
.db $de, %1110, $d8, %0100
.db $de, %1111, $78, %0101
.db $df, %0000, $45, %0001
.db $df, %0001, $45, %0001
.db $df, %0010, $45, %0001
.db $df, %0011, $45, %0001
.db $df, %0100, $df, %0100
.db $df, %0101, $7f, %0101
.db $df, %0110, $d9, %0100
.db $df, %0111, $79, %0101
.db $df, %1000, $45, %0001
.db $df, %1001, $45, %0001
.db $df, %1010, $45, %0001
.db $df, %1011, $45, %0001
.db $df, %1100, $df, %0100
.db $df, %1101, $7f, %0101
.db $df, %1110, $d9, %0100
.db $df, %1111, $79, %0101
.db $e0, %0000, $40, %0001
.db $e0, %0001, $40, %0001
.db $e0, %0010, $46, %0001
.db $e0, %0011, $46, %0001
.db $e0, %0100, $e0, %0100
.db $e0, %0101, $80, %0101
.db $e0, %0110, $da, %0100
.db $e0, %0111, $7a, %0101
.db $e0, %1000, $40, %0001
.db $e0, %1001, $40, %0001
.db $e0, %1010, $46, %0001
.db $e0, %1011, $46, %0001
.db $e0, %1100, $e0, %0100
.db $e0, %1101, $80, %0101
.db $e0, %1110, $da, %0100
.db $e0, %1111, $7a, %0101
.db $e1, %0000, $41, %0001
.db $e1, %0001, $41, %0001
.db $e1, %0010, $47, %0001
.db $e1, %0011, $47, %0001
.db $e1, %0100, $e1, %0100
.db $e1, %0101, $81, %0101
.db $e1, %0110, $db, %0100
.db $e1, %0111, $7b, %0101
.db $e1, %1000, $41, %0001
.db $e1, %1001, $41, %0001
.db $e1, %1010, $47, %0001
.db $e1, %1011, $47, %0001
.db $e1, %1100, $e1, %0100
.db $e1, %1101, $81, %0101
.db $e1, %1110, $db, %0100
.db $e1, %1111, $7b, %0101
.db $e2, %0000, $42, %0001
.db $e2, %0001, $42, %0001
.db $e2, %0010, $48, %0001
.db $e2, %0011, $48, %0001
.db $e2, %0100, $e2, %0100
.db $e2, %0101, $82, %0101
.db $e2, %0110, $dc, %0100
.db $e2, %0111, $7c, %0101
.db $e2, %1000, $42, %0001
.db $e2, %1001, $42, %0001
.db $e2, %1010, $48, %0001
.db $e2, %1011, $48, %0001
.db $e2, %1100, $e2, %0100
.db $e2, %1101, $82, %0101
.db $e2, %1110, $dc, %0100
.db $e2, %1111, $7c, %0101
.db $e3, %0000, $43, %0001
.db $e3, %0001, $43, %0001
.db $e3, %0010, $49, %0001
.db $e3, %0011, $49, %0001
.db $e3, %0100, $e3, %0100
.db $e3, %0101, $83, %0101
.db $e3, %0110, $dd, %0100
.db $e3, %0111, $7d, %0101
.db $e3, %1000, $43, %0001
.db $e3, %1001, $43, %0001
.db $e3, %1010, $49, %0001
.db $e3, %1011, $49, %0001
.db $e3, %1100, $e3, %0100
.db $e3, %1101, $83, %0101
.db $e3, %1110, $dd, %0100
.db $e3, %1111, $7d, %0101
.db $e4, %0000, $44, %0001
.db $e4, %0001, $44, %0001
.db $e4, %0010, $4a, %0001
.db $e4, %0011, $4a, %0001
.db $e4, %0100, $e4, %0100
.db $e4, %0101, $84, %0101
.db $e4, %0110, $de, %0100
.db $e4, %0111, $7e, %0101
.db $e4, %1000, $44, %0001
.db $e4, %1001, $44, %0001
.db $e4, %1010, $4a, %0001
.db $e4, %1011, $4a, %0001
.db $e4, %1100, $e4, %0100
.db $e4, %1101, $84, %0101
.db $e4, %1110, $de, %0100
.db $e4, %1111, $7e, %0101
.db $e5, %0000, $45, %0001
.db $e5, %0001, $45, %0001
.db $e5, %0010, $4b, %0001
.db $e5, %0011, $4b, %0001
.db $e5, %0100, $e5, %0100
.db $e5, %0101, $85, %0101
.db $e5, %0110, $df, %0100
.db $e5, %0111, $7f, %0101
.db $e5, %1000, $45, %0001
.db $e5, %1001, $45, %0001
.db $e5, %1010, $4b, %0001
.db $e5, %1011, $4b, %0001
.db $e5, %1100, $e5, %0100
.db $e5, %1101, $85, %0101
.db $e5, %1110, $df, %0100
.db $e5, %1111, $7f, %0101
.db $e6, %0000, $46, %0001
.db $e6, %0001, $46, %0001
.db $e6, %0010, $4c, %0001
.db $e6, %0011, $4c, %0001
.db $e6, %0100, $e6, %0100
.db $e6, %0101, $86, %0101
.db $e6, %0110, $e0, %0100
.db $e6, %0111, $80, %0101
.db $e6, %1000, $46, %0001
.db $e6, %1001, $46, %0001
.db $e6, %1010, $4c, %0001
.db $e6, %1011, $4c, %0001
.db $e6, %1100, $e6, %0100
.db $e6, %1101, $86, %0101
.db $e6, %1110, $e0, %0100
.db $e6, %1111, $80, %0101
.db $e7, %0000, $47, %0001
.db $e7, %0001, $47, %0001
.db $e7, %0010, $4d, %0001
.db $e7, %0011, $4d, %0001
.db $e7, %0100, $e7, %0100
.db $e7, %0101, $87, %0101
.db $e7, %0110, $e1, %0100
.db $e7, %0111, $81, %0101
.db $e7, %1000, $47, %0001
.db $e7, %1001, $47, %0001
.db $e7, %1010, $4d, %0001
.db $e7, %1011, $4d, %0001
.db $e7, %1100, $e7, %0100
.db $e7, %1101, $87, %0101
.db $e7, %1110, $e1, %0100
.db $e7, %1111, $81, %0101
.db $e8, %0000, $48, %0001
.db $e8, %0001, $48, %0001
.db $e8, %0010, $4e, %0001
.db $e8, %0011, $4e, %0001
.db $e8, %0100, $e8, %0100
.db $e8, %0101, $88, %0101
.db $e8, %0110, $e2, %0100
.db $e8, %0111, $82, %0101
.db $e8, %1000, $48, %0001
.db $e8, %1001, $48, %0001
.db $e8, %1010, $4e, %0001
.db $e8, %1011, $4e, %0001
.db $e8, %1100, $e8, %0100
.db $e8, %1101, $88, %0101
.db $e8, %1110, $e2, %0100
.db $e8, %1111, $82, %0101
.db $e9, %0000, $49, %0001
.db $e9, %0001, $49, %0001
.db $e9, %0010, $4f, %0001
.db $e9, %0011, $4f, %0001
.db $e9, %0100, $e9, %0100
.db $e9, %0101, $89, %0101
.db $e9, %0110, $e3, %0100
.db $e9, %0111, $83, %0101
.db $e9, %1000, $49, %0001
.db $e9, %1001, $49, %0001
.db $e9, %1010, $4f, %0001
.db $e9, %1011, $4f, %0001
.db $e9, %1100, $e9, %0100
.db $e9, %1101, $89, %0101
.db $e9, %1110, $e3, %0100
.db $e9, %1111, $83, %0101
.db $ea, %0000, $50, %0001
.db $ea, %0001, $50, %0001
.db $ea, %0010, $50, %0001
.db $ea, %0011, $50, %0001
.db $ea, %0100, $ea, %0100
.db $ea, %0101, $8a, %0101
.db $ea, %0110, $e4, %0100
.db $ea, %0111, $84, %0101
.db $ea, %1000, $50, %0001
.db $ea, %1001, $50, %0001
.db $ea, %1010, $50, %0001
.db $ea, %1011, $50, %0001
.db $ea, %1100, $ea, %0100
.db $ea, %1101, $8a, %0101
.db $ea, %1110, $e4, %0100
.db $ea, %1111, $84, %0101
.db $eb, %0000, $51, %0001
.db $eb, %0001, $51, %0001
.db $eb, %0010, $51, %0001
.db $eb, %0011, $51, %0001
.db $eb, %0100, $eb, %0100
.db $eb, %0101, $8b, %0101
.db $eb, %0110, $e5, %0100
.db $eb, %0111, $85, %0101
.db $eb, %1000, $51, %0001
.db $eb, %1001, $51, %0001
.db $eb, %1010, $51, %0001
.db $eb, %1011, $51, %0001
.db $eb, %1100, $eb, %0100
.db $eb, %1101, $8b, %0101
.db $eb, %1110, $e5, %0100
.db $eb, %1111, $85, %0101
.db $ec, %0000, $52, %0001
.db $ec, %0001, $52, %0001
.db $ec, %0010, $52, %0001
.db $ec, %0011, $52, %0001
.db $ec, %0100, $ec, %0100
.db $ec, %0101, $8c, %0101
.db $ec, %0110, $e6, %0100
.db $ec, %0111, $86, %0101
.db $ec, %1000, $52, %0001
.db $ec, %1001, $52, %0001
.db $ec, %1010, $52, %0001
.db $ec, %1011, $52, %0001
.db $ec, %1100, $ec, %0100
.db $ec, %1101, $8c, %0101
.db $ec, %1110, $e6, %0100
.db $ec, %1111, $86, %0101
.db $ed, %0000, $53, %0001
.db $ed, %0001, $53, %0001
.db $ed, %0010, $53, %0001
.db $ed, %0011, $53, %0001
.db $ed, %0100, $ed, %0100
.db $ed, %0101, $8d, %0101
.db $ed, %0110, $e7, %0100
.db $ed, %0111, $87, %0101
.db $ed, %1000, $53, %0001
.db $ed, %1001, $53, %0001
.db $ed, %1010, $53, %0001
.db $ed, %1011, $53, %0001
.db $ed, %1100, $ed, %0100
.db $ed, %1101, $8d, %0101
.db $ed, %1110, $e7, %0100
.db $ed, %1111, $87, %0101
.db $ee, %0000, $54, %0001
.db $ee, %0001, $54, %0001
.db $ee, %0010, $54, %0001
.db $ee, %0011, $54, %0001
.db $ee, %0100, $ee, %0100
.db $ee, %0101, $8e, %0101
.db $ee, %0110, $e8, %0100
.db $ee, %0111, $88, %0101
.db $ee, %1000, $54, %0001
.db $ee, %1001, $54, %0001
.db $ee, %1010, $54, %0001
.db $ee, %1011, $54, %0001
.db $ee, %1100, $ee, %0100
.db $ee, %1101, $8e, %0101
.db $ee, %1110, $e8, %0100
.db $ee, %1111, $88, %0101
.db $ef, %0000, $55, %0001
.db $ef, %0001, $55, %0001
.db $ef, %0010, $55, %0001
.db $ef, %0011, $55, %0001
.db $ef, %0100, $ef, %0100
.db $ef, %0101, $8f, %0101
.db $ef, %0110, $e9, %0100
.db $ef, %0111, $89, %0101
.db $ef, %1000, $55, %0001
.db $ef, %1001, $55, %0001
.db $ef, %1010, $55, %0001
.db $ef, %1011, $55, %0001
.db $ef, %1100, $ef, %0100
.db $ef, %1101, $8f, %0101
.db $ef, %1110, $e9, %0100
.db $ef, %1111, $89, %0101
.db $f0, %0000, $50, %0001
.db $f0, %0001, $50, %0001
.db $f0, %0010, $56, %0001
.db $f0, %0011, $56, %0001
.db $f0, %0100, $f0, %0100
.db $f0, %0101, $90, %0101
.db $f0, %0110, $ea, %0100
.db $f0, %0111, $8a, %0101
.db $f0, %1000, $50, %0001
.db $f0, %1001, $50, %0001
.db $f0, %1010, $56, %0001
.db $f0, %1011, $56, %0001
.db $f0, %1100, $f0, %0100
.db $f0, %1101, $90, %0101
.db $f0, %1110, $ea, %0100
.db $f0, %1111, $8a, %0101
.db $f1, %0000, $51, %0001
.db $f1, %0001, $51, %0001
.db $f1, %0010, $57, %0001
.db $f1, %0011, $57, %0001
.db $f1, %0100, $f1, %0100
.db $f1, %0101, $91, %0101
.db $f1, %0110, $eb, %0100
.db $f1, %0111, $8b, %0101
.db $f1, %1000, $51, %0001
.db $f1, %1001, $51, %0001
.db $f1, %1010, $57, %0001
.db $f1, %1011, $57, %0001
.db $f1, %1100, $f1, %0100
.db $f1, %1101, $91, %0101
.db $f1, %1110, $eb, %0100
.db $f1, %1111, $8b, %0101
.db $f2, %0000, $52, %0001
.db $f2, %0001, $52, %0001
.db $f2, %0010, $58, %0001
.db $f2, %0011, $58, %0001
.db $f2, %0100, $f2, %0100
.db $f2, %0101, $92, %0101
.db $f2, %0110, $ec, %0100
.db $f2, %0111, $8c, %0101
.db $f2, %1000, $52, %0001
.db $f2, %1001, $52, %0001
.db $f2, %1010, $58, %0001
.db $f2, %1011, $58, %0001
.db $f2, %1100, $f2, %0100
.db $f2, %1101, $92, %0101
.db $f2, %1110, $ec, %0100
.db $f2, %1111, $8c, %0101
.db $f3, %0000, $53, %0001
.db $f3, %0001, $53, %0001
.db $f3, %0010, $59, %0001
.db $f3, %0011, $59, %0001
.db $f3, %0100, $f3, %0100
.db $f3, %0101, $93, %0101
.db $f3, %0110, $ed, %0100
.db $f3, %0111, $8d, %0101
.db $f3, %1000, $53, %0001
.db $f3, %1001, $53, %0001
.db $f3, %1010, $59, %0001
.db $f3, %1011, $59, %0001
.db $f3, %1100, $f3, %0100
.db $f3, %1101, $93, %0101
.db $f3, %1110, $ed, %0100
.db $f3, %1111, $8d, %0101
.db $f4, %0000, $54, %0001
.db $f4, %0001, $54, %0001
.db $f4, %0010, $5a, %0001
.db $f4, %0011, $5a, %0001
.db $f4, %0100, $f4, %0100
.db $f4, %0101, $94, %0101
.db $f4, %0110, $ee, %0100
.db $f4, %0111, $8e, %0101
.db $f4, %1000, $54, %0001
.db $f4, %1001, $54, %0001
.db $f4, %1010, $5a, %0001
.db $f4, %1011, $5a, %0001
.db $f4, %1100, $f4, %0100
.db $f4, %1101, $94, %0101
.db $f4, %1110, $ee, %0100
.db $f4, %1111, $8e, %0101
.db $f5, %0000, $55, %0001
.db $f5, %0001, $55, %0001
.db $f5, %0010, $5b, %0001
.db $f5, %0011, $5b, %0001
.db $f5, %0100, $f5, %0100
.db $f5, %0101, $95, %0101
.db $f5, %0110, $ef, %0100
.db $f5, %0111, $8f, %0101
.db $f5, %1000, $55, %0001
.db $f5, %1001, $55, %0001
.db $f5, %1010, $5b, %0001
.db $f5, %1011, $5b, %0001
.db $f5, %1100, $f5, %0100
.db $f5, %1101, $95, %0101
.db $f5, %1110, $ef, %0100
.db $f5, %1111, $8f, %0101
.db $f6, %0000, $56, %0001
.db $f6, %0001, $56, %0001
.db $f6, %0010, $5c, %0001
.db $f6, %0011, $5c, %0001
.db $f6, %0100, $f6, %0100
.db $f6, %0101, $96, %0101
.db $f6, %0110, $f0, %0100
.db $f6, %0111, $90, %0101
.db $f6, %1000, $56, %0001
.db $f6, %1001, $56, %0001
.db $f6, %1010, $5c, %0001
.db $f6, %1011, $5c, %0001
.db $f6, %1100, $f6, %0100
.db $f6, %1101, $96, %0101
.db $f6, %1110, $f0, %0100
.db $f6, %1111, $90, %0101
.db $f7, %0000, $57, %0001
.db $f7, %0001, $57, %0001
.db $f7, %0010, $5d, %0001
.db $f7, %0011, $5d, %0001
.db $f7, %0100, $f7, %0100
.db $f7, %0101, $97, %0101
.db $f7, %0110, $f1, %0100
.db $f7, %0111, $91, %0101
.db $f7, %1000, $57, %0001
.db $f7, %1001, $57, %0001
.db $f7, %1010, $5d, %0001
.db $f7, %1011, $5d, %0001
.db $f7, %1100, $f7, %0100
.db $f7, %1101, $97, %0101
.db $f7, %1110, $f1, %0100
.db $f7, %1111, $91, %0101
.db $f8, %0000, $58, %0001
.db $f8, %0001, $58, %0001
.db $f8, %0010, $5e, %0001
.db $f8, %0011, $5e, %0001
.db $f8, %0100, $f8, %0100
.db $f8, %0101, $98, %0101
.db $f8, %0110, $f2, %0100
.db $f8, %0111, $92, %0101
.db $f8, %1000, $58, %0001
.db $f8, %1001, $58, %0001
.db $f8, %1010, $5e, %0001
.db $f8, %1011, $5e, %0001
.db $f8, %1100, $f8, %0100
.db $f8, %1101, $98, %0101
.db $f8, %1110, $f2, %0100
.db $f8, %1111, $92, %0101
.db $f9, %0000, $59, %0001
.db $f9, %0001, $59, %0001
.db $f9, %0010, $5f, %0001
.db $f9, %0011, $5f, %0001
.db $f9, %0100, $f9, %0100
.db $f9, %0101, $99, %0101
.db $f9, %0110, $f3, %0100
.db $f9, %0111, $93, %0101
.db $f9, %1000, $59, %0001
.db $f9, %1001, $59, %0001
.db $f9, %1010, $5f, %0001
.db $f9, %1011, $5f, %0001
.db $f9, %1100, $f9, %0100
.db $f9, %1101, $99, %0101
.db $f9, %1110, $f3, %0100
.db $f9, %1111, $93, %0101
.db $fa, %0000, $60, %0001
.db $fa, %0001, $60, %0001
.db $fa, %0010, $60, %0001
.db $fa, %0011, $60, %0001
.db $fa, %0100, $fa, %0100
.db $fa, %0101, $9a, %0101
.db $fa, %0110, $f4, %0100
.db $fa, %0111, $94, %0101
.db $fa, %1000, $60, %0001
.db $fa, %1001, $60, %0001
.db $fa, %1010, $60, %0001
.db $fa, %1011, $60, %0001
.db $fa, %1100, $fa, %0100
.db $fa, %1101, $9a, %0101
.db $fa, %1110, $f4, %0100
.db $fa, %1111, $94, %0101
.db $fb, %0000, $61, %0001
.db $fb, %0001, $61, %0001
.db $fb, %0010, $61, %0001
.db $fb, %0011, $61, %0001
.db $fb, %0100, $fb, %0100
.db $fb, %0101, $9b, %0101
.db $fb, %0110, $f5, %0100
.db $fb, %0111, $95, %0101
.db $fb, %1000, $61, %0001
.db $fb, %1001, $61, %0001
.db $fb, %1010, $61, %0001
.db $fb, %1011, $61, %0001
.db $fb, %1100, $fb, %0100
.db $fb, %1101, $9b, %0101
.db $fb, %1110, $f5, %0100
.db $fb, %1111, $95, %0101
.db $fc, %0000, $62, %0001
.db $fc, %0001, $62, %0001
.db $fc, %0010, $62, %0001
.db $fc, %0011, $62, %0001
.db $fc, %0100, $fc, %0100
.db $fc, %0101, $9c, %0101
.db $fc, %0110, $f6, %0100
.db $fc, %0111, $96, %0101
.db $fc, %1000, $62, %0001
.db $fc, %1001, $62, %0001
.db $fc, %1010, $62, %0001
.db $fc, %1011, $62, %0001
.db $fc, %1100, $fc, %0100
.db $fc, %1101, $9c, %0101
.db $fc, %1110, $f6, %0100
.db $fc, %1111, $96, %0101
.db $fd, %0000, $63, %0001
.db $fd, %0001, $63, %0001
.db $fd, %0010, $63, %0001
.db $fd, %0011, $63, %0001
.db $fd, %0100, $fd, %0100
.db $fd, %0101, $9d, %0101
.db $fd, %0110, $f7, %0100
.db $fd, %0111, $97, %0101
.db $fd, %1000, $63, %0001
.db $fd, %1001, $63, %0001
.db $fd, %1010, $63, %0001
.db $fd, %1011, $63, %0001
.db $fd, %1100, $fd, %0100
.db $fd, %1101, $9d, %0101
.db $fd, %1110, $f7, %0100
.db $fd, %1111, $97, %0101
.db $fe, %0000, $64, %0001
.db $fe, %0001, $64, %0001
.db $fe, %0010, $64, %0001
.db $fe, %0011, $64, %0001
.db $fe, %0100, $fe, %0100
.db $fe, %0101, $9e, %0101
.db $fe, %0110, $f8, %0100
.db $fe, %0111, $98, %0101
.db $fe, %1000, $64, %0001
.db $fe, %1001, $64, %0001
.db $fe, %1010, $64, %0001
.db $fe, %1011, $64, %0001
.db $fe, %1100, $fe, %0100
.db $fe, %1101, $9e, %0101
.db $fe, %1110, $f8, %0100
.db $fe, %1111, $98, %0101
.db $ff, %0000, $65, %0001
.db $ff, %0001, $65, %0001
.db $ff, %0010, $65, %0001
.db $ff, %0011, $65, %0001
.db $ff, %0100, $ff, %0100
.db $ff, %0101, $9f, %0101
.db $ff, %0110, $f9, %0100
.db $ff, %0111, $99, %0101
.db $ff, %1000, $65, %0001
.db $ff, %1001, $65, %0001
.db $ff, %1010, $65, %0001
.db $ff, %1011, $65, %0001
.db $ff, %1100, $ff, %0100
.db $ff, %1101, $9f, %0101
.db $ff, %1110, $f9, %0100
.db $ff, %1111, $99, %0101
.ends

.ramsection "Test-HRAM" slot HRAM_SLOT
  hram.f db
  hram.a db
  hram.testcase_l db
  hram.testcase_h db
  hram.sp_save_l db
  hram.sp_save_h db
.ends
